<?php
namespace PME\Controllers\Expedicao;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class ControleExpedicaoController extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $environment;
    protected $birtStrategy;
    protected $newCode;
    protected $connection;
	  protected $utilities;

    public function __construct(ReportService $reportService, $entityManager, $environment, $birtStrategy, $newCode, $connection, $utilities) {
      $this->entityManager = $entityManager;
      $this->environment = $environment;
      $this->birtStrategy = $birtStrategy;
      $this->newCode      = $newCode;
      $this->connection   = $connection;
      $this->utilities    = $utilities;

      parent::__construct($reportService);
    }

    protected $reportMapping = array (
      'PME02800' => array (
        'strategy' => 'BIRT',
        'parameterMapping' => array (
          "NRORG"         => "P_NRORG",
          "CDFILCENTPME"  => "P_CDFILCENTPME",
          "NRCONSPLAN"    => "P_NRCONSPLAN",
          "DTDE"          => "P_DTINI",
          "DTATE"         => "P_DTFIN",
          "CDARVPRODINI"  => "P_CDPRODINI",
          "CDARVPRODFIN"  => "P_CDPROFIN",
          "IDTPREQPROD"   => "P_IDTPREQPROD",
          "NRLISTASERV"   => "L_CDSERVFILI",
          "NRLISTATPCARD" => "L_CDTIPOCARD",
          "CDPICTPRAT"    => "P_CDPICTPRAT"
        )
      ),
      'PME02801' => array (
        'strategy' => 'BIRT',
        'parameterMapping' => array (
          "NRORG"         => "P_NRORG",
          "CDFILCENTPME"  => "P_CDFILCENTPME",
          "NRCONSPLAN"    => "P_NRCONSPLAN",
          "DTDE"          => "P_DTINI",
          "DTATE"         => "P_DTFIN",
          "CDARVPRODINI"  => "P_CDPRODINI",
          "CDARVPRODFIN"  => "P_CDPROFIN",
          "IDTPREQPROD"   => "P_IDTPREQPROD",
          "NRLISTASERV"   => "L_CDSERVFILI",
          "NRLISTATPCARD" => "L_CDTIPOCARD",
          "CDPICTPRAT"    => "P_CDPICTPRAT"
        )
      ),
    );
    
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
      try{
        $row = $request->getRow();
        
        $nrorg = $this->environment->getNrOrg();
        $row['NRORG'] = $nrorg;
        
        $row['IDTPREQPROD'] = '';
        if (\Zeedhi\Framework\Util\Functions::arrayKeyExists('IDENT_PREPARACAO', $row) and $row['IDENT_PREPARACAO']) $row['IDTPREQPROD'] = 'P_';
        if (\Zeedhi\Framework\Util\Functions::arrayKeyExists('IDENT_DISTRIBUICAO', $row) and $row['IDENT_DISTRIBUICAO']) $row['IDTPREQPROD'] = $row['IDTPREQPROD'] . 'D';
        
        if(empty($row['CDARVPRODINI'])) $row['CDARVPRODINI'] = 0;
        if(empty($row['CDARVPRODFIN'])) $row['CDARVPRODFIN'] = "Z";
        
        $row['CDARVPRODFIN'] = str_pad($row['CDARVPRODFIN'], 20, "Z", STR_PAD_RIGHT);

        if ((empty($row['SERVICO']) && !empty($row['GRUPSERV'])) ||
          (empty($row['SERVICO']) && empty($row['GRUPSERV']))
        ){
          $row['NRLISTASERV'] = $this->geraListaServicosGrupo($row);
        } else if(is_array($row['SERVICO'])){
          $row['NRLISTASERV'] = join("_", $row['SERVICO']);
        }
      
        if($row['TIPOCARD'] === null) {
          $row['NRLISTATPCARD'] = $this->geraListaTipoCard($row);
        } else {
          $row['TIPOCARD'] = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
          $row['NRLISTATPCARD'] = $this->geraListaTipoCard($row);
        }

        $row['NRCONSPLAN'] = $this->utilities->consumoPlanPMe($row['CDFILCENTPME'], $row['TIPOCARD'], $row['UNIDADE'], $row['SERVICO'], $row['DTDE'], $row['DTATE'], 'C', $idprodutos = 'CXX',
                                 'P', 0, 'N', $row['CDARVPRODINI'], $row['CDARVPRODFIN']);

        $this->birtStrategy->setReportFormat(strtolower($row['reportFormat']));
      } catch(\Exception $e) {
        $response->setError(new DTO\Response\Error($e->getMessage(), 1));
      }
    }
    
    private function geraListaTipoCard($row) {
      if(empty($row['TIPOCARD'])) $cdtipocard = 'T';
      else $cdtipocard = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
      
      $nrorg = $this->environment->getNrOrg();
      $nrlista = $this->newCode->getCodeByTableName('LISTA_TIPOCARD', $nrorg);
  
      $sql = "INSERT INTO LISTA_TIPOCARD (CDFILCENTPME, CDTIPOCARD, NRLISTA, NMTIPOCARD, NRORG)
                SELECT CDFILCENTPME, CDTIPOCARD, :NRLISTA AS NRLISTA, NMTIPOCARD, NRORG 
                  FROM TIPOCARD 
                 WHERE CDFILCENTPME = :CDFILCENTPME 
                   AND ( INSTR(:CDTIPOCARD, CDTIPOCARD) <> 0 OR ( :CDTIPOCARD = 'T' ) )";
      $stmt = $this->entityManager->getConnection()->prepare($sql);
      $stmt->execute(
        array(
          "NRLISTA"      => $nrlista,
          "CDFILCENTPME" => $row['CDFILCENTPME'],
          "CDTIPOCARD" => $cdtipocard
        )
      );
    
      return $nrlista;
    }
    
    private function geraListaServicosGrupo($rows) {
      $nrorg = $this->environment->getNrOrg();
      $nrlista = $this->newCode->getCodeByTableName('LISTA_SERVICO', $nrorg);
      
      if (empty($row['GRUPSERV'])) $grupserv = 'T';
      else $grupserv = $row['GRUPSERV'];
  
      $sql = "INSERT INTO LISTA_SERVICO (NRLISTA, CDFILIAL, CDSERVFILI, NMSERVICO, NRORG)
                SELECT :NRLISTA AS NRLISTA, S.CDFILIAL, S.CDSERVFILI, S.NMSERVICO, S.NRORG 
                  FROM SERVICO S
                 WHERE ( ( INSTR(:CDGRUPSERV, S.CDGRUPSERV) <> 0 ) OR ( :CDGRUPSERV = 'T' ) ) 
                   AND ( S.CDFILIAL IN (SELECT CDFILIAL FROM FILIAL WHERE CDFILCENTPME  = :CDFILCENTPME ) ) AND S.IDTIPOSERV = 'M'";
      $stmt = $this->entityManager->getConnection()->prepare($sql);
      $stmt->execute(
        array(
          "NRLISTA"    => $nrlista,
          "CDGRUPSERV" => $grupserv,
          "CDFILCENTPME" => $rows["CDFILCENTPME"]
        )
      );
    
      return $nrlista;
    }
}