<?php
namespace PME\Controllers\Parametrizacao;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use DateTime;

class AtualizarComensaisCardController extends \PME\Services\TeknisaCrud {
	protected $crudService;
	protected $parameterBag;
	protected $connection;
	protected $armazenaResultado;
	protected $armazenaCentral;
	protected $environment;
	protected $newCode;

    public function __construct($crudService, $parameterBag, $connection, $environment, $newCode) {
        parent::__construct($crudService, $parameterBag); 
        $this->connection = $connection;
        $this->environment = $environment;
        $this->newCode = $newCode;
	}
	
	public function buscaComensaisUnidade(DTO\Request $request, DTO\Response $response, $atualizaCentral = false) {
		try {
			$row = $request->getRow();
			$this->connection->beginTransaction();
		
			if(empty($row['UNIDADE'])) $unidade = 'T';
	        else $unidade = is_array($row['UNIDADE']) ? join("_", $row['UNIDADE']) : $row['UNIDADE'];
	        
	        if(empty($row['TIPOCARD'])) $tipocard = 'T';
	        else $tipocard = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
	        
	        if(empty($row['SERVICO'])) $servico = 'T';
	        else $servico = is_array($row['SERVICO']) ? join("_", $row['SERVICO']) : $row['SERVICO'];
			
			$query = "SELECT CO.CDFILCENTPME, CO.CDTIPOCARD, CO.CDFILIAL, CO.CDSERVFILI, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCOMPMESEG END, 0.0 ) AS QTCOMPMESEG, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCOMPMETER END, 0.0 ) AS QTCOMPMETER, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCOMPMEQUA END, 0.0 ) AS QTCOMPMEQUA, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCOMPMEQUI END, 0.0 ) AS QTCOMPMEQUI, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCOMPMESEX END, 0.0 ) AS QTCOMPMESEX, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCOMPMESAB END, 0.0 ) AS QTCOMPMESAB, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCOMPMEDOM END, 0.0 ) AS QTCOMPMEDOM, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCOMPMEFER END, 0.0 ) AS QTCOMPMEFER, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCLIPMESEG END, 0.0 ) AS QTCLIPMESEG, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCLIPMETER END, 0.0 ) AS QTCLIPMETER, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCLIPMEQUA END, 0.0 ) AS QTCLIPMEQUA, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCLIPMEQUI END, 0.0 ) AS QTCLIPMEQUI, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCLIPMESEX END, 0.0 ) AS QTCLIPMESEX, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCLIPMESAB END, 0.0 ) AS QTCLIPMESAB, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCLIPMEDOM END, 0.0 ) AS QTCLIPMEDOM, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTCLIPMEFER END, 0.0 ) AS QTCLIPMEFER, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTFUNPMESEG END, 0.0 ) AS QTFUNPMESEG, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTFUNPMETER END, 0.0 ) AS QTFUNPMETER, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTFUNPMEQUA END, 0.0 ) AS QTFUNPMEQUA, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTFUNPMEQUI END, 0.0 ) AS QTFUNPMEQUI, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTFUNPMESEX END, 0.0 ) AS QTFUNPMESEX, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTFUNPMESAB END, 0.0 ) AS QTFUNPMESAB, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTFUNPMEDOM END, 0.0 ) AS QTFUNPMEDOM, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTFUNPMEFER END, 0.0 ) AS QTFUNPMEFER, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTDOAPMESEG END, 0.0 ) AS QTDOAPMESEG, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTDOAPMETER END, 0.0 ) AS QTDOAPMETER, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTDOAPMEQUA END, 0.0 ) AS QTDOAPMEQUA, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTDOAPMEQUI END, 0.0 ) AS QTDOAPMEQUI, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTDOAPMESEX END, 0.0 ) AS QTDOAPMESEX, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTDOAPMESAB END, 0.0 ) AS QTDOAPMESAB, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTDOAPMEDOM END, 0.0 ) AS QTDOAPMEDOM, 
							NVL( CASE WHEN F.CDFILCENTPME IS NULL THEN 0.0 ELSE QTDOAPMEFER END, 0.0 ) AS QTDOAPMEFER 
					   FROM COMESERVTCAR CO 
					   LEFT JOIN FILITIPOCARD F ON F.CDFILCENTPME = CO.CDFILCENTPME AND F.CDTIPOCARD = CO.CDTIPOCARD AND F.CDFILIAL = CO.CDFILIAL AND NVL(F.IDTCARATFILI, 'N') = 'S' 
					  WHERE ( CO.CDFILCENTPME = :P_CDFILCENTPME ) AND (CO.CDFILIAL <> :P_CDFILCENTPME) 
					    AND ( ( INSTR(:P_CDFILIAL, CO.CDFILIAL) > 0 ) OR (:P_CDFILIAL = 'T') ) 
					    AND ( ( INSTR(:P_CDTIPOCARD, CO.CDTIPOCARD) > 0 ) OR (:P_CDTIPOCARD = 'T') ) 
					    AND ( ( INSTR(:P_CDSERVFILI, CO.CDSERVFILI) > 0 ) OR (:P_CDSERVFILI = 'T') ) 
					    AND EXISTS ( SELECT 1 FROM FILIAL FI WHERE FI.CDFILIAL = CO.CDFILIAL AND FI.CDFILCENTPME = CO.CDFILCENTPME )";
			$params = array(
	            "P_CDFILCENTPME" => $row["CDFILCENTPME"],
	            "P_CDFILIAL"     => $unidade,
	            "P_CDTIPOCARD"   => $tipocard,
	            "P_CDSERVFILI"   => $servico
			);
			$stmt = $this->connection->prepare($query);
			$stmt->execute($params);
	        $result = $stmt->fetchAll();
	        $armazenaResultado = $result;
	
	        $this->updateComensaisSemana($request, $response, $armazenaResultado);
	        $this->updateComensaisFeriado($request, $response, $armazenaResultado);
	        
	        if ($atualizaCentral) $this->buscaTotalCentral($request, $response);
	        
	        $this->connection->commit();
		} catch (\Exception $e) {
			$this->connection->rollback();
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function updateComensaisSemana(DTO\Request $request, DTO\Response $response, $armazenaResultado){
		try {
			// $armazenaResultado = comensais por unidade/servico
			$row = $request->getRow();
			
	        $dataProc = DateTime::createFromFormat('d/m/Y', $row['DTPROC']);
	        $dataIniCard = DateTime::createFromFormat('d/m/Y', $row['PERIODODE']);
			$row['PERIODODE'] = ($dataProc >= $dataIniCard) ? $row['DTPROC'] : $row['PERIODODE'];
			// if ($row['DTPROC'] >= $row['PERIODODE']) $row['PERIODODE'] = $row['DTPROC'];
			
	        foreach($armazenaResultado as $pos){
				$cardia = "SELECT CARDAPIOPME.CDFILCENTPME, TO_CHAR(CARDAPIOPME.DTINICARDPME, 'DD/MM/YYYY') AS DTINICARDPME, 
			    				TO_CHAR(CARDAPIOPME.DTFINCARDPME, 'DD/MM/YYYY') AS DTFINCARDPME, CARDAPIOPME.CDTIPOCARD, 
								CARDAPIOPME.NRCARDPME, CARDIAPME.CDFILIAL, CARDIAPME.NRCARDIAPME, TO_CHAR(CARDIAPME.DTCARDIAPME, 'DD/MM/YYYY') as DTCARDIAPME,
								CARDIAPME.CDSERVFILI, TO_CHAR(CARDIAPME.DTCARDIAPME, 'D') AS DIASEMANA,
								CARDAPIOPME.NRCARDPME || TO_CHAR(CARDIAPME.DTCARDIAPME, 'DD/MM/YYYY') || CARDIAPME.CDFILIAL AS CHAVE
			    		   FROM CARDAPIOPME 
						   LEFT JOIN CARDIAPME ON ( CARDAPIOPME.CDFILCENTPME = CARDIAPME.CDFILCENTPME )
											   AND ( CARDAPIOPME.NRCARDPME = CARDIAPME.NRCARDPME )
											   AND ( CARDIAPME.DTCARDIAPME BETWEEN :P_DATAINI AND :P_DATAFIN ) 
											   AND ( CARDIAPME.CDFILIAL IN (:P_CDFILIAL,  CARDIAPME.CDFILCENTPME))
											   AND ( CARDIAPME.CDSERVFILI = :P_CDSERVFILI )
									   AND ( NOT EXISTS (
												SELECT DTFERIFILI
												  FROM FERIFILI FF
												 WHERE FF.DTFERIFILI = CARDIAPME.DTCARDIAPME
												   AND FF.CDFILIAL = CARDIAPME.CDFILIAL
											) )
						   WHERE CARDAPIOPME.CDFILCENTPME = :P_CDFILCENTPME AND CARDAPIOPME.CDTIPOCARD = :P_CDTIPOCARD 
			    		   AND (:P_DATAINI BETWEEN CARDAPIOPME.DTINICARDPME AND CARDAPIOPME.DTFINCARDPME 
			    				OR :P_DATAFIN BETWEEN CARDAPIOPME.DTINICARDPME AND CARDAPIOPME.DTFINCARDPME 
			    				OR CARDAPIOPME.DTINICARDPME BETWEEN :P_DATAINI AND :P_DATAFIN 
			    				OR CARDAPIOPME.DTFINCARDPME BETWEEN :P_DATAINI AND :P_DATAFIN)
						  ORDER BY CARDAPIOPME.NRCARDPME, CARDIAPME.DTCARDIAPME, 
								DECODE(CARDIAPME.CDFILIAL, CARDAPIOPME.CDFILCENTPME, 99999, 1), CARDIAPME.CDFILIAL";
									
				$paramCardia = array(
					"P_CDFILCENTPME" => $pos['CDFILCENTPME'],
					"P_CDFILIAL"     => $pos['CDFILIAL'],
					"P_CDSERVFILI"   => $pos['CDSERVFILI'],
					"P_DATAINI"      => $row['PERIODODE'],
					"P_DATAFIN"      => $row['PERIODOATE'],
					"P_CDTIPOCARD"   => $pos['CDTIPOCARD']
					);
		        $resultCardia = $this->connection->fetchAll($cardia, $paramCardia);
       
		        if (count($resultCardia) > 0) {
		        	foreach ($resultCardia as $cardadiapme) {
		        		if ($pos['CDFILIAL'] == $cardadiapme['CDFILIAL']) {
		        			$manipulacao = "UPDATE CARDIAPME
										   SET QTFUNESTCPME = DECODE(TO_CHAR(DTCARDIAPME, 'D'), 1, :P_QTFUNPMEDOM, 2, :P_QTFUNPMESEG,
										                             3, :P_QTFUNPMETER, 4, :P_QTFUNPMEQUA, 5,
										                             :P_QTFUNPMEQUI, 6, :P_QTFUNPMESEX, 7, :P_QTFUNPMESAB),
										       QTDOAESTCPME = DECODE(TO_CHAR(DTCARDIAPME, 'D'), 1, :P_QTDOAPMEDOM, 2, :P_QTDOAPMESEG,
										                             3, :P_QTDOAPMETER, 4, :P_QTDOAPMEQUA, 5,
										                             :P_QTDOAPMEQUI, 6, :P_QTDOAPMESEX, 7, :P_QTDOAPMESAB),
										       QTCLIESTCPME = DECODE(TO_CHAR(DTCARDIAPME, 'D'), 1, :P_QTCLIPMEDOM, 2, :P_QTCLIPMESEG,
										                             3, :P_QTCLIPMETER, 4, :P_QTCLIPMEQUA, 5,
										                             :P_QTCLIPMEQUI, 6, :P_QTCLIPMESEX, 7, :P_QTCLIPMESAB),
										       QTCOMESTCPME = DECODE(TO_CHAR(DTCARDIAPME, 'D'), 1, :P_QTCOMPMEDOM, 2, :P_QTCOMPMESEG,
										                             3, :P_QTCOMPMETER, 4, :P_QTCOMPMEQUA, 5,
										                             :P_QTCOMPMEQUI, 6, :P_QTCOMPMESEX, 7, :P_QTCOMPMESAB)
										 WHERE ( CDFILCENTPME = :P_CDFILCENTPME )
										   AND ( CDFILIAL = :P_CDFILIAL )
										   AND ( CDSERVFILI = :P_CDSERVFILI )
										   AND ( NRCARDPME = :P_NRCARDPME )
										   AND ( NRCARDIAPME = :P_NRCARDIAPME )";
										   
							$paramManipulacao = array(
								"P_QTFUNPMEDOM"  => $pos['QTFUNPMEDOM'],
								"P_QTFUNPMESEG"  => $pos['QTFUNPMESEG'],
								"P_QTFUNPMETER"  => $pos['QTFUNPMETER'],
								"P_QTFUNPMEQUA"  => $pos['QTFUNPMEQUA'],
								"P_QTFUNPMEQUI"  => $pos['QTFUNPMEQUI'],
								"P_QTFUNPMESEX"  => $pos['QTFUNPMESEX'],
								"P_QTFUNPMESAB"  => $pos['QTFUNPMESAB'],
								"P_QTDOAPMEDOM"  => $pos['QTDOAPMEDOM'],
								"P_QTDOAPMESEG"  => $pos['QTDOAPMESEG'],
								"P_QTDOAPMETER"  => $pos['QTDOAPMETER'],
								"P_QTDOAPMEQUA"  => $pos['QTDOAPMEQUA'],
								"P_QTDOAPMEQUI"  => $pos['QTDOAPMEQUI'],
								"P_QTDOAPMESEX"  => $pos['QTDOAPMESEX'],
								"P_QTDOAPMESAB"  => $pos['QTDOAPMESAB'],
								"P_QTCLIPMEDOM"  => $pos['QTCLIPMEDOM'],
								"P_QTCLIPMESEG"  => $pos['QTCLIPMESEG'],
								"P_QTCLIPMETER"  => $pos['QTCLIPMETER'],
								"P_QTCLIPMEQUA"  => $pos['QTCLIPMEQUA'],
								"P_QTCLIPMEQUI"  => $pos['QTCLIPMEQUI'],
								"P_QTCLIPMESEX"  => $pos['QTCLIPMESEX'],
								"P_QTCLIPMESAB"  => $pos['QTCLIPMESAB'],
								"P_QTCOMPMEDOM"  => $pos['QTCOMPMEDOM'],
								"P_QTCOMPMESEG"  => $pos['QTCOMPMESEG'],
								"P_QTCOMPMETER"  => $pos['QTCOMPMETER'],
								"P_QTCOMPMEQUA"  => $pos['QTCOMPMEQUA'],
								"P_QTCOMPMEQUI"  => $pos['QTCOMPMEQUI'],
								"P_QTCOMPMESEX"  => $pos['QTCOMPMESEX'],
								"P_QTCOMPMESAB"  => $pos['QTCOMPMESAB'],
								"P_CDFILCENTPME" => $cardadiapme['CDFILCENTPME'],
								"P_CDFILIAL"     => $cardadiapme['CDFILIAL'],
								"P_CDSERVFILI"   => $cardadiapme['CDSERVFILI'],
								"P_NRCARDPME"    => $cardadiapme['NRCARDPME'],
								"P_NRCARDIAPME"  => $cardadiapme['NRCARDIAPME']
							);
		        
						    $stmt = $this->connection->prepare($manipulacao);
							$stmt->execute($paramManipulacao);
		        		} else if ($cardadiapme['CDFILCENTPME'] == $cardadiapme['CDFILIAL']) {
		        			$search = $cardadiapme['NRCARDPME'].$cardadiapme['DTCARDIAPME'].$pos['CDFILIAL'];
		        			// retorna o registro da unidade filtrada; se não existir, insere.
		        			$retornaCardPorDia = array_keys(
		        					array_filter(
		        						$resultCardia,
		        						function ($value) use ($search) {return (strpos($value['CHAVE'], $search) !== false);})
		        				);
		        				
		        			if (count($retornaCardPorDia) == 0 and $row['INSEREAGREG']) {
		        				$nrorg = $this->environment->getNrOrg();
								switch($cardadiapme['DIASEMANA']) {
									case '1' : // domingo
										$comensais = $pos['QTCOMPMEDOM'];
										$cliente = $pos['QTCLIPMEDOM'];
										$funcionario = $pos['QTFUNPMEDOM'];
										$doacao = $pos['QTDOAPMEDOM'];
										break;
									case '2' : // segunda
										$comensais = $pos['QTCOMPMESEG'];
										$cliente = $pos['QTCLIPMESEG'];
										$funcionario = $pos['QTFUNPMESEG'];
										$doacao = $pos['QTDOAPMESEG'];
										break;
									case '3' : // terca
										$comensais = $pos['QTCOMPMETER'];
										$cliente = $pos['QTCLIPMETER'];
										$funcionario = $pos['QTFUNPMETER'];
										$doacao = $pos['QTDOAPMETER'];
										break;
									case '4' : // quarta
										$comensais = $pos['QTCOMPMEQUA'];
										$cliente = $pos['QTCLIPMEQUA'];
										$funcionario = $pos['QTFUNPMEQUA'];
										$doacao = $pos['QTDOAPMEQUA'];
										break;
									case '5' : // quinta
										$comensais = $pos['QTCOMPMEQUI'];
										$cliente = $pos['QTCLIPMEQUI'];
										$funcionario = $pos['QTFUNPMEQUI'];
										$doacao = $pos['QTDOAPMEQUI'];
										break;
									case '6' : // sexta
										$comensais = $pos['QTCOMPMESEX'];
										$cliente = $pos['QTCLIPMESEX'];
										$funcionario = $pos['QTFUNPMESEX'];
										$doacao = $pos['QTDOAPMESEX'];
										break;
									case '7' : // sabado
										$comensais = $pos['QTCOMPMESAB'];
										$cliente = $pos['QTCLIPMESAB'];
										$funcionario = $pos['QTFUNPMESAB'];
										$doacao = $pos['QTDOAPMESAB'];
										break;
									default : 
										$comensais = 0;
										$cliente = 0;
										$funcionario = 0;
										$doacao = 0;
										break;
								}
								
								$newNrcardiapme  = $this->newCode->getCodeByTableName('CARDIAPME'.$cardadiapme['CDFILCENTPME'].$cardadiapme['NRCARDPME'], $nrorg);
								
								$newCardia = "INSERT INTO CARDIAPME (CDFILCENTPME, NRCARDPME, NRCARDIAPME, CDSERVFILI, CDFILIAL, DTCARDIAPME, QTCOMESTCPME, QTCLIESTCPME, QTFUNESTCPME, QTDOAESTCPME, QTCOMEFECPME, QTCLIEFECPME, QTFUNEFECPME, QTDOAEFECPME, IDCARDESPEC) VALUES (:CDFILCENTPME, :NRCARDPME, :NRCARDIAPME, :CDSERVFILI, :CDFILIAL, :DTCARDIAPME, :QTCOMESTCPME, :QTCLIESTCPME, :QTFUNESTCPME, :QTDOAESTCPME, :QTCOMEFECPME, :QTCLIEFECPME, :QTFUNEFECPME, :QTDOAEFECPME, :IDCARDESPEC)";
								$insertNewCardia = array(
										"CDFILCENTPME" => $cardadiapme['CDFILCENTPME'],
										"NRCARDPME"    => $cardadiapme['NRCARDPME'],
										"NRCARDIAPME"  => $newNrcardiapme,
										"CDSERVFILI"   => $cardadiapme['CDSERVFILI'],
										"CDFILIAL"     => $pos['CDFILIAL'],
										"DTCARDIAPME"  => $cardadiapme['DTCARDIAPME'],
										"QTCOMESTCPME" => $comensais, 
										"QTCLIESTCPME" => $cliente,
										"QTFUNESTCPME" => $funcionario, 
										"QTDOAESTCPME" => $doacao,
										"QTCOMEFECPME" => 0, 
										"QTCLIEFECPME" => 0, 
										"QTFUNEFECPME" => 0, 
										"QTDOAEFECPME" => 0,
										"IDCARDESPEC"  => 'N'
								);
		        
							    $stmt = $this->connection->prepare($newCardia);
								$stmt->execute($insertNewCardia);
		        			}
		        		}
		        	}
		        }
	        }
	    } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function updateComensaisFeriado(DTO\Request $request, DTO\Response $response, $armazenaResultado){
		try{
			$row = $request->getRow();
			foreach($armazenaResultado as $pos){
				$data = array(
					"P_QTFUNPMEFER"  => $pos['QTFUNPMEFER'],
					"P_QTDOAPMEFER"  => $pos['QTDOAPMEFER'],
					"P_QTCLIPMEFER"  => $pos['QTCLIPMEFER'],
					"P_QTCOMPMEFER"  => $pos['QTCOMPMEFER'],
					"P_CDFILCENTPME" => $pos['CDFILCENTPME'],
					"P_CDFILIAL"     => $pos['CDFILIAL'],
					"P_CDSERVFILI"   => $pos['CDSERVFILI'],
					"P_DATAINI"      => $row['PERIODODE'],
					"P_DATAFIN"      => $row['PERIODOATE'],
					"P_CDTIPOCARD"   => $pos['CDTIPOCARD']
				);
		    	$query = "UPDATE CARDIAPME SET QTFUNESTCPME = :P_QTFUNPMEFER, QTDOAESTCPME = :P_QTDOAPMEFER, QTCLIESTCPME = :P_QTCLIPMEFER, 
		    	QTCOMESTCPME = :P_QTCOMPMEFER 
		    	WHERE (CDFILCENTPME = :P_CDFILCENTPME) AND (CDFILIAL = :P_CDFILIAL)         AND (CDSERVFILI = :P_CDSERVFILI)     
		    	AND (DTCARDIAPME  BETWEEN :P_DATAINI AND :P_DATAFIN) 
		    	AND (EXISTS (SELECT CARDAPIOPME.NRCARDPME FROM CARDAPIOPME WHERE (CARDAPIOPME.CDFILCENTPME = CARDIAPME.CDFILCENTPME) 
		    	AND (CARDAPIOPME.NRCARDPME = CARDIAPME.NRCARDPME) AND (DTCARDIAPME BETWEEN CARDAPIOPME.DTINICARDPME AND CARDAPIOPME.DTFINCARDPME) 
		    	AND (CARDAPIOPME.CDTIPOCARD = :P_CDTIPOCARD) ) )
		    	AND (EXISTS (SELECT DTFERIFILI FROM FERIFILI FF WHERE FF.DTFERIFILI = CARDIAPME.DTCARDIAPME AND FF.CDFILIAL = CARDIAPME.CDFILIAL))";
		    	$stmt = $this->connection->prepare($query);
				$stmt->execute($data);
			}
		} catch(\Exception $e){
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function buscaTotalCentral(DTO\Request $request, DTO\Response $response){
		try {
			$row = $request->getRow();
			$this->connection->beginTransaction();
        
	        if(empty($row['TIPOCARD'])) $tipocard = 'T';
	        else $tipocard = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
	        
	        if(empty($row['SERVICO'])) $servico = 'T';
	        else $servico = is_array($row['SERVICO']) ? join("_", $row['SERVICO']) : $row['SERVICO'];

	        $dataProc = DateTime::createFromFormat('d/m/Y', $row['DTPROC']);
	        $dataIniCard = DateTime::createFromFormat('d/m/Y', $row['PERIODODE']);
			$row['PERIODODE'] = ($dataProc > $dataIniCard) ? $row['DTPROC'] : $row['PERIODODE'];
	        
			//if ($row['DTPROC'] >= $row['PERIODODE']) $row['PERIODODE'] = $row['DTPROC'];
	        
		    $query = "SELECT CA.CDFILCENTPME, CA.CDSERVFILI, TO_DATE(TO_CHAR(CA.DTCARDIAPME, 'DD/MM/YYYY')) AS DTCARDIAPME, CP.CDTIPOCARD, CA.NRCARDPME, 
		    				SUM(CA.QTCOMESTCPME) AS QTCOMESTCPME, SUM(CA.QTCLIESTCPME) AS QTCLIESTCPME, SUM(CA.QTFUNESTCPME) AS QTFUNESTCPME, 
		    				SUM(CA.QTDOAESTCPME) AS QTDOAESTCPME 
		    		   FROM CARDIAPME CA, CARDAPIOPME CP 
		    		  WHERE (CA.CDFILCENTPME = :P_CDFILCENTPME) AND (CP.CDFILCENTPME = CA.CDFILCENTPME) AND (CP.NRCARDPME = CA.NRCARDPME) 
		    		    AND ((INSTR(:P_CDTIPOCARD, CP.CDTIPOCARD) >0) OR (:P_CDTIPOCARD  = 'T')) AND (CA.CDFILIAL <> :P_CDFILCENTPME) 
		    		    AND ((INSTR(:P_CDSERVFILI, CA.CDSERVFILI) >0) OR (:P_CDSERVFILI  = 'T')) AND (CA.IDCARDESPEC <> 'S') 
		    		    AND (CA.DTCARDIAPME BETWEEN :P_DATAINI AND :P_DATAFIN) 
		    		  GROUP BY CA.CDFILCENTPME, CA.CDSERVFILI, CP.CDTIPOCARD, CA.NRCARDPME, CA.DTCARDIAPME";
		    $params = array(
	            "P_CDFILCENTPME" => $row["CDFILCENTPME"],
	            "P_CDTIPOCARD"   => $tipocard,
	            "P_CDSERVFILI"   => $servico,
	            "P_DATAINI"      => $row['PERIODODE'],
	            "P_DATAFIN"      => $row['PERIODOATE']
	        );
	        $stmt = $this->connection->prepare($query);
			$stmt->execute($params);
	        $result = $stmt->fetchAll();
	        $armazenaCentral = $result;
	
	        $this->atulizaComensaisDia($request, $response, $armazenaCentral);
			
			$this->connection->commit();
		} catch (\Exception $e){
			$this->connection->rollback();
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function atulizaComensaisDia(DTO\Request $request, DTO\Response $response, $armazenaCentral){
		try {
			$row = $request->getRow();
	        foreach($armazenaCentral as $pos){
				$data = array(
					"P_QTFUNESTCPME" => $pos['QTFUNESTCPME'],
					"P_QTDOAESTCPME" => $pos['QTDOAESTCPME'],
					"P_QTCLIESTCPME" => $pos['QTCLIESTCPME'],
					"P_QTCOMESTCPME" => $pos['QTCOMESTCPME'],
					"P_CDFILCENTPME" => $pos['CDFILCENTPME'],
					"P_CDFILCENTPME" => $pos['CDFILCENTPME'],
					"P_CDSERVFILI"   => $pos['CDSERVFILI'],
					"P_DTCARDIAPME"  => substr($pos['DTCARDIAPME'], 0, 10),
					"P_CDTIPOCARD"   => $pos['CDTIPOCARD']	
				);
	    		$query = "UPDATE CARDIAPME		
	    					 SET QTFUNESTCPME = :P_QTFUNESTCPME, QTDOAESTCPME = :P_QTDOAESTCPME, QTCLIESTCPME = :P_QTCLIESTCPME, 
	    						 QTCOMESTCPME = :P_QTCOMESTCPME 
	    				  WHERE (CDFILCENTPME = :P_CDFILCENTPME) AND (CDFILIAL = :P_CDFILCENTPME)         
	    				    AND (CDSERVFILI = :P_CDSERVFILI)     AND (TO_DATE(TO_CHAR(DTCARDIAPME, 'DD/MM/YYYY')) = :P_DTCARDIAPME)   
	    				    AND (EXISTS (SELECT CARDAPIOPME.NRCARDPME FROM CARDAPIOPME WHERE (CARDAPIOPME.CDFILCENTPME = CARDIAPME.CDFILCENTPME) 
	    				    	AND (CARDAPIOPME.NRCARDPME = CARDIAPME.NRCARDPME) AND (DTCARDIAPME BETWEEN CARDAPIOPME.DTINICARDPME AND CARDAPIOPME.DTFINCARDPME) 
	    				    	AND (CARDAPIOPME.CDTIPOCARD = :P_CDTIPOCARD) ) )
	    				    AND (NOT EXISTS (SELECT DTFERIFILI FROM FERIFILI FF WHERE FF.DTFERIFILI = CARDIAPME.DTCARDIAPME AND FF.CDFILIAL = CARDIAPME.CDFILIAL ) )";
			    $stmt = $this->connection->prepare($query);
				$stmt->execute($data);
	        }
	    } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
}