<?php
namespace PME\Controllers\Parametrizacao;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class ParametrosPlanejamentoController {
	protected $connection;
	protected $environment;
	protected $crudService;
	protected $newCode;

    public function __construct($connection, $environment, $crudService, $newCode) {
    	$this->connection = $connection;
    	$this->environment = $environment;
    	$this->crudService = $crudService;
    	$this->newCode     = $newCode;
	}

  public function updateParamGeral(DTO\Request $request, DTO\Response $response) {
    try {
        $row = $request->getRow();
        
        $nrorg = $this->environment->getNrOrg();
    	  
    	  $this->connection->beginTransaction();
        
        $queryUpdate = 'UPDATE PARAMGERAL 
                           SET QTDIABLOQCAR = :P_QTDIABLOQCAR, CDCARBOHIDRA = :P_CDCARBOHIDRA, CDPROTEINA = :P_CDPROTEINA, 
                               CDALCOOL = :P_CDALCOOL, CDLIPIDIOS = :P_CDLIPIDIOS, CDCALORIAS = :P_CDCALORIAS, 
                               CDACIDGRAXOS = :P_CDACIDGRAXOS, CDACUCARES = :P_CDACUCARES, IDUTRPADCA = :P_IDUTRPADCA,
                              IDBLOPRATLOC = :P_IDBLOPRATLOC, IDBLOQPRADUP = :P_IDBLOQPRADUP, IDPERCOMENSPRAT = :P_IDPERCOMENSPRAT';
    	  
      	$params = array(
          "P_QTDIABLOQCAR"  => $row["QTDIABLOQCAR"],
          "P_CDCARBOHIDRA"  => $row["CDCARBOHIDRA"],
          "P_CDPROTEINA"    => $row["CDPROTEINA"],
          "P_CDALCOOL"      => $row["CDALCOOL"],
          "P_CDLIPIDIOS"    => $row["CDLIPIDIOS"],
          "P_CDCALORIAS"    => $row["CDCALORIAS"],
          "P_CDACIDGRAXOS"  => $row["CDACIDGRAXOS"],
          "P_CDACUCARES"    => $row["CDACUCARES"],
          "P_IDUTRPADCA"    => $row["IDUTRPADCA"],
          "P_IDBLOPRATLOC"  => $row["IDBLOPRATLOC"],
          "P_IDBLOQPRADUP"  => $row["IDBLOQPRADUP"],
          "P_IDPERCOMENSPRAT"=> $row["IDPERCOMENSPRAT"]
        );
        
        $std = $this->connection->prepare($queryUpdate);
        $std->execute($params); 
                         
        $queryGERUpdate = 'UPDATE GERPARAMGERAL 
                           SET IDPERMSELCENTRALPLA = :P_IDPERMSELCENTRALPLA';
        
        $paramsGER = array(
          "P_IDPERMSELCENTRALPLA" => $row["IDPERMSELCENTRALPLA"]
        );
        
        $stdGER = $this->connection->prepare($queryGERUpdate);
        $stdGER->execute($paramsGER); 
        
        $this->connection->commit();
        $response->addDataSet(new DataSet("success", array(true)));
    } catch (\Exception $e) {
    	$this->connection->rollback();
		  $response->setError(new Error($e->getMessage(), 500));
	  }
  }
  
  public function updateParamPlaneja(DTO\Request $request, DTO\Response $response) {
    try {
        $row = (Array) $request->getRow();

        if ($row['tab'] === 'MensCard') {
          $queryUpdate = 'UPDATE PARAMPLANEJA SET TXMENSCARDIA = :P_TXMENSCARDIA, TXMENSCARSEM = :P_TXMENSCARSEM  WHERE CDFILIAL = :P_CDFILIAL';
        	$params = array(
            "P_TXMENSCARDIA"    => $row["TXMENSCARDIA"],
            "P_TXMENSCARSEM"    => $row["TXMENSCARSEM"],
            "P_CDFILIAL"        => $row["CDFILIAL"]
          );
        }
        
        if ($row['tab'] === 'ConfPrato') {
          $queryUpdate = 'UPDATE PARAMPLANEJA SET IDQTLIQUBRUT = :P_IDQTLIQUBRUT, IDBLOALTRELO = :P_IDBLOALTRELO WHERE CDFILIAL = :P_CDFILIAL';
        	$params = array(
            "P_IDQTLIQUBRUT"    => $row["IDQTLIQUBRUT"],
            "P_CDFILIAL"        => $row["CDFILIAL"],
            "P_IDBLOALTRELO"    => $row["IDBLOALTRELO"]
          );
        }
        
        if ($row['tab'] === 'ReqRetirada') {
          $queryUpdate = 'UPDATE PARAMPLANEJA SET CDTCACONSPER = :P_CDTCACONSPER, CDTCACONSFIX = :P_CDTCACONSFIX, CDTPRCONSFIX = :P_CDTPRCONSFIX, CDTPRCONSPER = :P_CDTPRCONSPER WHERE CDFILIAL = :P_CDFILIAL';
        	$params = array(
            "P_CDTCACONSPER"    => $row["CDTCACONSPER"],
            "P_CDTCACONSFIX"    => $row["CDTCACONSFIX"],
            "P_CDTPRCONSFIX"    => $row["CDTPRCONSFIX"],
            "P_CDTPRCONSPER"    => $row["CDTPRCONSPER"],
            "P_CDFILIAL"        => $row["CDFILIAL"]
          );
        }
        
        if ($row['tab'] === 'Elaboracao') {
          $queryUpdate = 'UPDATE PARAMPLANEJA SET CDTIPOCUSTOPLA = :P_CDTIPOCUSTOPLA, CDTIPOCUSTOREA = :P_CDTIPOCUSTOREA, IDEXIBECUSTO = :P_IDEXIBECUSTO, IDPERCCOME = :P_IDPERCCOME  WHERE CDFILIAL = :P_CDFILIAL';
        	$params = array(
            "P_CDTIPOCUSTOPLA"    => $row["CDTIPOCUSTOPLA"],
            "P_CDTIPOCUSTOREA"    => $row["CDTIPOCUSTOREA"],
            "P_IDEXIBECUSTO"      => $row["IDEXIBECUSTO"],
            "P_IDPERCCOME"        => $row["IDPERCCOME"],
            "P_CDFILIAL"          => $row["CDFILIAL"]
          );
        }
        
        if ($row['tab'] === 'Planejamento') {
          $queryUpdate = 'UPDATE PARAMPLANEJA SET IDCARDIAUTIL = :P_IDCARDIAUTIL, IDCONSGRPRAT = :P_IDCONSGRPRAT, IDSERVINCFILAGR = :P_IDSERVINCFILAGR, IDCUSPADCAR = :P_IDCUSPADCAR, CDSERVRETPME = :P_CDSERVRETPME, CDNUTRRELAT1 = :P_CDNUTRRELAT1, CDNUTRRELAT2 = :P_CDNUTRRELAT2, CDNUTRRELAT3 = :P_CDNUTRRELAT3, CDNUTRRELAT4 = :P_CDNUTRRELAT4, IDPRINVENRETI = :P_IDPRINVENRETI, CDTPRETIPADR = :P_CDTPRETIPADR WHERE CDFILIAL = :P_CDFILIAL';
        	$params = array(
            "P_IDCARDIAUTIL"      => $row["IDCARDIAUTIL"],
            "P_IDCONSGRPRAT"      => $row["IDCONSGRPRAT"],
            "P_IDSERVINCFILAGR"   => $row["IDSERVINCFILAGR"],
            "P_IDCUSPADCAR"       => $row["IDCUSPADCAR"],
            "P_CDSERVRETPME"      => $row["CDSERVRETPME"],
            "P_CDNUTRRELAT1"      => $row["CDNUTRRELAT1"],
            "P_CDNUTRRELAT2"      => $row["CDNUTRRELAT2"],
            "P_CDNUTRRELAT3"      => $row["CDNUTRRELAT3"],
            "P_CDNUTRRELAT4"      => $row["CDNUTRRELAT4"],
            "P_IDPRINVENRETI"     => $row["IDPRINVENRETI"],
            "P_CDTPRETIPADR"      => $row["CDTPRETIPADR"],
            "P_CDFILIAL"          => $row["CDFILIAL"]
          );
        }
        
        if ($row['tab'] === 'SafraCard') {
          $queryUpdate = 'UPDATE PARAMPLANEJA SET NRCORCARDESP = :P_NRCORCARDESP, NRCORNUTIL = :P_NRCORNUTIL, NRCORNALTE = :P_NRCORNALTE, NRCORSAFRA = :P_NRCORSAFRA,  NRCORINICSAF = :P_NRCORINICSAF, NRCORENTRSAF = :P_NRCORENTRSAF WHERE CDFILIAL = :P_CDFILIAL';
        	$params = array(
            "P_NRCORCARDESP"      => $row["NRCORCARDESP"],
            "P_NRCORNUTIL"        => $row["NRCORNUTIL"],
            "P_NRCORNALTE"        => $row["NRCORNALTE"],
            "P_NRCORSAFRA"        => $row["NRCORSAFRA"],
            "P_NRCORINICSAF"      => $row["NRCORINICSAF"],
            "P_NRCORENTRSAF"      => $row["NRCORENTRSAF"],
            "P_CDFILIAL"          => $row["CDFILIAL"]
          );
        }

    	  $this->connection->beginTransaction();
    	  
        $std = $this->connection->prepare($queryUpdate);
        $std->execute($params); 
        
        if ($row['tab'] === 'Planejamento') {
          $queryUpdate = 'UPDATE PARAMFILIAL SET IDCOMCUSPERC = :P_IDCOMCUSPERC, IDUTRETBASEINVE = :P_IDUTRETBASEINVE WHERE CDFILIAL = :P_CDFILIAL';
          $params = array(
            "P_IDCOMCUSPERC"    => $row["IDCOMCUSPERC"],
            "P_IDUTRETBASEINVE" => $row["IDUTRETBASEINVE"],
            "P_CDFILIAL"        => $row["CDFILIAL"]
          );
          
          $std = $this->connection->prepare($queryUpdate);
          $std->execute($params); 
        }
        
        $this->connection->commit();
        $response->addDataSet(new DataSet("success", array(true)));
    } catch (\Exception $e) {
    	$this->connection->rollback();
		  $response->setError(new Error($e->getMessage(), 500));
	  }
  }
  
  public function updateGrupOper(DTO\Request\Row $request, DTO\Response $response) {
    try {
      $row = $request->getRow();
      $permissions = $row['permissions'];
	    $currentRow = $row['currentRow'];
	    
	    $autperfilacesso = $this->getAutPerfilAcesso();
	        
	    $orderPermissionsSelect = array_column($autperfilacesso, 'IDAUTPERFACESSO'); 
	    $basicRow = array(
	      'CDOPERINCLUSAO' => $this->environment->getCdOperador(),
	      'NRORGINCLUSAO'  => $this->environment->getNrOrg(),
	      'CDOPERULTATU'   => $this->environment->getCdOperador(),
	      'NRORGULTATU'    => $this->environment->getNrOrg(),
	      'NRORG'          => $this->environment->getNrOrg()
	    );
	    
	    
	    $this->connection->beginTransaction();
	      
	    foreach($permissions as $namePermission => $information) {
	      $index = array_search($namePermission, $orderPermissionsSelect);
        if($index === false && isset($currentRow) && $currentRow) {
          $rowToInsert = $basicRow;
  	      $rowToInsert['NRAUTPERFACESSO'] = $this->newCode->getCodeByTableName('AUTPERFILACESSO'.$rowToInsert['NRORG'], $rowToInsert['NRORG']);
  	      $rowToInsert['NRPERFILACESSO']  = $currentRow;
  	      $rowToInsert['IDAUTPERFACESSO'] = $namePermission;
  	      $rowToInsert['DSAUTPERFACESSO'] = $information['label'];
  	      $this->insertAutPerfilAcesso($this->connection, $rowToInsert);
  	     } else if(!isset($currentRow) || (isset($currentRow) && !$currentRow)){
  	       $rowToDelete = $basicRow;
  	       $rowToDelete['IDAUTPERFACESSO'] = $namePermission;
  	       $this->deleteAutPerfilAcesso($this->connection, $rowToDelete);
  	     } else if(isset($currentRow) && $currentRow !==  $autperfilacesso[$index]['NRPERFILACESSO']){
  	       $rowToUpdate = $basicRow;
  	       $rowToUpdate["NRPERFILACESSO"] = $currentRow;
  	       $rowToUpdate['IDAUTPERFACESSO'] = $namePermission;
  	       $this->updateAutPerfilAcesso($this->connection, $rowToUpdate);
  	     }
	     }
  	     
	     $this->connection->commit();
	  } catch (\Exception $e) {
  	   $this->connection->rollback();
	     $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
    }
	}
	
	private function getAutPerfilAcesso(){
	    $dataSourceName = 'autperfilAcesso';
	    $result = $this->crudService->getFilteredDataSet($dataSourceName, array())->getRows();
      return $result;
	}
	
	private function insertAutPerfilAcesso($connection, $row){
	    $sql = "INSERT INTO AUTPERFILACESSO ( NRAUTPERFACESSO, NRPERFILACESSO, IDAUTPERFACESSO, DSAUTPERFACESSO, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTPERFACESSO, :NRPERFILACESSO, :IDAUTPERFACESSO, :DSAUTPERFACESSO, :NRORG, SYSDATE, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
	   $params = array(
	     "NRAUTPERFACESSO" => $row['NRAUTPERFACESSO'],
       "NRPERFILACESSO"  => $row['NRPERFILACESSO'],
       "IDAUTPERFACESSO" => $row['IDAUTPERFACESSO'],
       "DSAUTPERFACESSO" => $row['DSAUTPERFACESSO'],
       "NRORG"           => $row['NRORG'],
       "NRORGINCLUSAO"   => $row['NRORGINCLUSAO'],
       "CDOPERINCLUSAO"  => $row['CDOPERINCLUSAO'],
       "NRORGULTATU"     => $row['NRORGULTATU'],
       "CDOPERULTATU"    => $row['CDOPERULTATU']
	   );
	   
	    $stmt = $connection->prepare($sql);
      $stmt->execute($params);
	}
	
	public function deleteAutPerfilAcesso($connection, $row){
	    $sql = "DELETE FROM AUTPERFILACESSO WHERE IDAUTPERFACESSO = :IDAUTPERFACESSO ";
	    $params = array(
	        "IDAUTPERFACESSO" => $row['IDAUTPERFACESSO']
	    );
	    $stmt = $connection->prepare($sql);
	    $stmt->execute($params);
	}
	
	public function updateAutPerfilAcesso($connection, $row){
	    $sql = "UPDATE AUTPERFILACESSO SET NRPERFILACESSO = :NRPERFILACESSO WHERE IDAUTPERFACESSO = :IDAUTPERFACESSO";
	    $params = array(
	        "NRPERFILACESSO"  => $row["NRPERFILACESSO"],
	        "IDAUTPERFACESSO" => $row["IDAUTPERFACESSO"]
	    );
	    $stmt = $connection->prepare($sql);
	    $stmt->execute($params);
	}
  
  private function callSave($dataSourceName, $rowsToSave){
    $dataSet = new DataSet($dataSourceName, $rowsToSave);
    $request = new DTO\Request\DataSet($dataSet, "", "", "");  
    $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceName);    
    $this->crudService->save($dataSourceName, $rowsToSave);
  }

  public function saveNDPCAL(DTO\Request\Row $request, DTO\Response $response) {
    $rows = $request->getParameters();
    $nrorg = $this->environment->getNrOrg();
    try {
      $this->connection->beginTransaction();
      foreach($rows['editedRows'] as $edited) {
        if ($edited['__is_new']) {
          $product = $this->verifyProduct($rows['editedRows']);
          if (count($product) === 0) {
            $this->insertNewRegisterNDPCAL($edited, $nrorg);
            $msg = array('message' => 'Salvo com sucesso!', 'type' => 'success');
          } else {
            $msg = array('message' => 'Produto já existente.', 'type' => 'error');
          }
        } else {
          $this->updatePlates($rows['editedRows']);
          $msg = array('message' => 'Salvo com sucesso!', 'type' => 'success');
        }
      }
      
      $this->connection->commit();
      $response->addDataSet(new DataSet("saveConfigCard", $msg));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new Error($e->getMessage(), 500));
    }
  }

  public function verifyProduct($rows){
    $sql = "SELECT CDARVPROD FROM NDPCAL N, PRODUTO P WHERE (P.CDPRODUTO = N.CDPRODUTO)   AND (:P_CDARVPROD LIKE P.CDARVPROD || '%')";

    foreach ($rows as $row) {
      $params = array(
        "P_CDARVPROD" => $row['NMPRODUTO']['CDARVPROD']
      );
    }

    $stmt = $this->connection->prepare($sql);
		$stmt->execute($params);
    $result = $stmt->fetchAll();
		return $result;
  }

  private function insertNewRegisterNDPCAL($edited, $nrorg) {
    $insert = "INSERT INTO NDPCAL (CDPRODUTO, VRFATCALNDPC, NRORG) VALUES (:CDPRODUTO, :VRFATCALNDPC, :NRORG)";
    
    $params = array(
      "CDPRODUTO"    => $edited['NMPRODUTO']['CDPRODUTO'],
      "VRFATCALNDPC" => $edited['VRFATCALNDPC'],
      "NRORG"	       => $nrorg
    );
        
    $stmt = $this->connection->prepare($insert);
    $stmt->execute($params);
  }

  private function updatePlates($edited) {
    $update = "UPDATE NDPCAL SET VRFATCALNDPC = :VRFATCALNDPC WHERE CDPRODUTO = :CDPRODUTO";
    
    foreach($edited as $row) {
      $params = array(
        "CDPRODUTO"    => $row['CDPRODUTO'],
        "VRFATCALNDPC" => $row['VRFATCALNDPC'] 
      );
        
      $stmt = $this->connection->prepare($update);
      $stmt->execute($params);
    }
  }
  
  public function insereParamgeral(DTO\Request\Row $request, DTO\Response $response) {
    $insert = "INSERT INTO PARAMGERAL (CDPARGERAL) VALUES ('0001')";
    $stmt = $this->connection->prepare($insert);
    $stmt->execute();
    
    $data = array(
        "CDCARBOHIDRA" => '',
        "CDPROTEINA"   => '',
        "CDALCOOL"     => '',
        "CDLIPIDIOS"   => '',
        "CDCALORIAS"   => '',
        "CDACIDGRAXOS" => '',
        "CDACUCARES"   => '',
        "IDUTRPADCA"   => 'N',
        "IDBLOPRATLOC" => 'N',
        "IDBLOQPRADUP" => 'N',
        "IDPERMSELCENTRALPLA" => 'N'
        );
        
    $response->addDataSet(new DataSet("data", $data));
  }
  
  public function insereGERParamgeral(DTO\Request\Row $request, DTO\Response $response) {
    $insert = "INSERT INTO GERPARAMGERAL (CDPARGERAL) VALUES ('0001')";
    $stmt = $this->connection->prepare($insert);
    $stmt->execute();
    
    $data = array("IDPERMSELCENTRALPLA" => 'N');
        
    $response->addDataSet(new DataSet("data", $data));
  }
  
  public function insertParamPlaneja(DTO\Request\Row $request, DTO\Response $response) {
    $row = $request->getRow();
    $unidade = $row['CDFILIAL'];

    $nrorg = $this->environment->getNrOrg();
    
    $data = $this->_insertParamPlaneja($unidade, $nrorg);
        
    $response->addDataSet(new DataSet("data", $data));
  }
  
  private function _insertParamPlaneja($unidade, $nrorg) {
    $sql    = "INSERT INTO PARAMPLANEJA (CDFILIAL, CDPARPLANEJA, IDPRINVENRETI, IDALTCOMCARD, 
                  IDBLOQNECCOMP, IDENVMAILCARD, IDRATEIORETGER) 
                VALUES (:CDFILIAL, '1', 'N', 'N', 'N', 'N', '1')";
    $params = array(
        "CDFILIAL" => $unidade
    );
    $stmt = $this->connection->prepare($sql);
    $stmt->execute($params);
    
    $data = array(
      "NRORG"           => $nrorg,
      "CDFILIAL"        => $unidade,
      "CDPARPLANEJA"    => '1',
      "IDCONSGRPRAT"    => 'N',
      "NRCORSAFRA"      => '4227072',
      "NRCORINICSAF"    => '8453888',
      "NRCORENTRSAF"    => '13154717',
      "IDCARDIAUTIL"    => 'N',
      "IDCONSGRPRAT"    => 'N',
      "IDSERVINCFILAGR" => 'N',
      "IDCUSPADCAR"     => 'N',
      "CDNUTRRELAT1"    => '',
      "CDNUTRRELAT2"    => '',
      "CDNUTRRELAT3"    => '',
      "CDNUTRRELAT4"    => '',
      "IDPRINVENRETI"   => 'N',
      "CDTPRETIPADR"    => '',
      "CDTIPOCUSTOPLA"  => '',
      "CDTIPOCUSTOREA"  => '',
      "IDEXIBECUSTO"    => '',
      "IDPERCCOME"      => 'C',
      "TXMENSCARDIA"    => '',
      "TXMENSCARSEM"    => '',
      "CDTCACONSFIX"    => '',
      "CDTCACONSPER"    => '',
      "NRCORNALTE"      => '255',
      "NRCORNUTIL"      => '255',
      "NRCORCARDESP"    => '16708284',
      "CDSERVRETPME"    => '',
      "IDQTLIQUBRUT"    => 'L',
      "IDBLOALTRELO"    => 'N'
    );
    return $data;
  }
  
  public function exportParamsUnidade(DTO\Request\Row $request, DTO\Response $response) {
    $row = $request->getRow();
    $nrorg = $this->environment->getNrOrg();
    $nrLista = "";
    try {
      $this->connection->beginTransaction();
      
      $filialOrigem = $row['CDFILIAL_ORIGEM'];
      if(!empty($row['CDFILIAL_DESTINO'])) {
        $allFiliaisDest = implode('_', array_unique(array_column($row['CDFILIAL_DESTINO'], 'CDFILIAL')));
        $nrLista = $this->insertLista($allFiliaisDest);
      }
      $result = $this->exportParams($request, $response, $nrLista, $filialOrigem, $row);
      if(!empty($row['CDFILIAL_DESTINO'])) $this->deleteLista($nrLista);

      $this->connection->commit();
      $response->addDataSet(new DataSet("exportParamsUnidade", []));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new Error($e->getMessage(), 500));
    }
  }
  
  private function exportParams($request, $response, $nrlista, $filialOrigem, $data){
    self::verifyExistParamPlanejaExport($request, $nrlista);
    $rowParamPlaneja = self::getParamsParamPlaneja($filialOrigem);
    // $rowUnidMediFili = self::getParamsUnidMediFili($filialOrigem);
    $allCdFilial = empty($data['CDFILIAL_DESTINO']) ? 'T' : '';
    
    if($data['subTabParametrosPlanejamento'] === 'S'){
      $rowParamFilial = self::getParamsParamFilial($filialOrigem);
      self::exportPlanejamento($request, $response, $nrlista, $rowParamPlaneja, $rowParamFilial, $allCdFilial);
    }
    
    if($data['subTabParametrosSafraECardapio'] === 'S'){
      self::exportSafraCard($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    }
    
    if($data['subTabParametrosElaboracaoCardapio'] === 'S'){
      self::exportElabCard($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    }
    
    // if($data['EFETIVOS'] === 'S'){
    //   self::exportEfetivos($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    // }
    
    if($data['subTabParametrosMsgCardapio'] === 'S'){
      self::exportMensCard($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    }

    // if($data['MENSCARSEMANAL'] === 'S'){
    //   self::exportMensCardSem($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    // }
    
    // if($data['MENSCARMENSAL'] === 'S'){
    //   self::exportMensCardMens($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    // }
    
    if($data['subTabParametrosReqRetirada'] === 'S'){
      self::exportReqRetPrato($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    }
    
    if($data['subTabParametrosConfPrato'] === 'S'){
      self::exportConfigPrato($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    }
    // if($data['DADOSTRANSPORTE'] === 'S'){
    //   self::exportDadosTransporte($request, $response, $nrlista, $rowParamPlaneja, $rowUnidMediFili, $allCdFilial);
    // }
    
    // if($data['CALCCONSPLA'] === 'S'){
    //   self::exportCalcConsPla($request, $response, $nrlista, $filialOrigem, $allCdFilial, $rowParamFilial);
    // }
    
    // if($data['PRODDIST'] === 'S'){
    //   self::exportProdDist($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial);
    // }
  }
 
  public function verifyExistParamPlanejaExport($request, $nrlista){
    // $filial = explode('_', $filialDestino);
    $sql = "SELECT CDLISTA FROM LISTA WHERE NRLISTA = :NRLISTA";
    $params = array(
        "NRLISTA"   =>  $nrlista
    );
    $query  = $this->connection->prepare($sql);
    $query->execute($params);
    $filiais = $query->fetchAll();
    foreach ($filiais as $key => &$fili){
      $sql    = "SELECT CDPARPLANEJA FROM PARAMPLANEJA WHERE CDFILIAL = :CDFILIAL";
      $params = array(
          "CDFILIAL" => $fili['CDLISTA']
      );
      $query  = $this->connection->prepare($sql);
      $query->execute($params);
      $result = $query->fetchAll();
      if (empty($result)) {
        $nrorg = $this->environment->getNrOrg();
        self::_insertParamPlaneja($fili['CDLISTA'], $nrorg);
      }
    }
  }
  
  public function getParamsParamPlaneja($filialOrigem){
    $sql = "SELECT NRORG, CDNUTRRELAT1, CDNUTRRELAT2, CDNUTRRELAT3, CDNUTRRELAT4, IDBLPRCUSZER, IDCARDIAUTIL, IDCUSPADCAR, 
                   IDRESTRCARD, IDRESTRAPROVCARD, IDACOMPCUSTO, IDCONSGRPRAT, IDSOMACOMEST, IDCALPADCMP, IDCARDIFRETI, VRINDCALCMP, 
                   CDTPRETIPADR, CDTPCUSTCMP, IDPRINVENRETI, IDBLOQNECCOMP, IDSERVINCFILAGR, IDENVMAILCARD, IDCONSPROD, IDPERCCOME, 
                   NRCORSAFRA, NRCORINICSAF, NRCORENTRSAF, NRCORNUTIL, NRCORNALTE, NRCORCARDESP, NRCORCARDREV, IDALTCOMCARD, 
                   VRPEMAXDIFPLAPA, VRPEMINDIFPLAPA, CDTIPOCUSTODESC, IDBLQFECHCARD, TXLAYOUTCATR, IDEFETCARDIA, IDPEREFEPOSDTPR, 
                   IDPERLEFESRETPLA, IDBLQEFEDIAFECH, NRDIAANTDTPROC, IDPEREFETFATMPLA, TXMENSCARDIA, TXMENSCARSEM, TXMENSCARMES, 
                   IDUTREQUPRAT, CDTCACONSPER, CDTPRCONSFIX, CDFILCONSFIX, CDPRACONSFIX, CDTCACONSFIX, CDFILCONSPER, CDTPRCONSPER, 
                   CDPRACONSPER, IDRATEIORETGER, IDEXIBESALDOESTRETI, IDQTLIQUBRUT, IDBLOALTRELO, VRPEMINCONT, IDPERCCOME, CDTIPOCUSTOPLA, 
                   CDTIPOCUSTOREA, IDEXIBECUSTO, CDTPDISTRSAID, CDTPDISTRENTR, QTDIAVALPRODA, QTVALIDPRODCONG, QTVALIDPRODRESF, 
                   IDUTLVALCARD, IDBLOQREQVALCARD, IDBLOQLIBCAVALCARD, IDBLOQAPRCAVALCARD, IDBLOQAPMATVALCARD, IDBLOQPREVCONVALCARD
              FROM PARAMPLANEJA WHERE CDFILIAL = :CDFILIAL AND CDPARPLANEJA = '1'";
    
    $params = array(
        "CDFILIAL" => $filialOrigem
    );
    
    $query  = $this->connection->prepare($sql);
    $query->execute($params);
    $result = $query->fetchAll();
    return $result;
  }
  
  public function getParamsParamFilial($filialOrigem){
    $sql = "SELECT IDUTRETBASEINVE, IDCOMCUSPERC, VRPERCENTACRES FROM PARAMFILIAL WHERE CDFILIAL = :CDFILIAL";
    $params = array(
        "CDFILIAL" => $filialOrigem
    );
    
    $query  = $this->connection->prepare($sql);
    $query->execute($params);
    $result = $query->fetchAll();
    return $result;
  }

  public function exportPlanejamento($request, $response, $nrlista, $rowParamPlaneja, $rowParamFilial, $allCdFilial){
    $sql = "UPDATE PARAMPLANEJA SET CDNUTRRELAT1 = :CDNUTRRELAT1, CDNUTRRELAT2 = :CDNUTRRELAT2, CDNUTRRELAT3 = :CDNUTRRELAT3, CDNUTRRELAT4 = :CDNUTRRELAT4, IDBLPRCUSZER = :IDBLPRCUSZER, IDCARDIAUTIL = :IDCARDIAUTIL, IDCUSPADCAR = :IDCUSPADCAR, IDRESTRCARD = :IDRESTRCARD, IDRESTRAPROVCARD = :IDRESTRAPROVCARD, IDACOMPCUSTO = :IDACOMPCUSTO, IDCONSGRPRAT = :IDCONSGRPRAT, IDSOMACOMEST = :IDSOMACOMEST, IDCALPADCMP = :IDCALPADCMP, IDCARDIFRETI = :IDCARDIFRETI, VRINDCALCMP = :VRINDCALCMP, CDTPRETIPADR = :CDTPRETIPADR, CDTPCUSTCMP = :CDTPCUSTCMP, IDPRINVENRETI = :IDPRINVENRETI, IDBLOQNECCOMP = :IDBLOQNECCOMP, IDSERVINCFILAGR = :IDSERVINCFILAGR, IDENVMAILCARD = :IDENVMAILCARD, IDUTLVALCARD = :IDUTLVALCARD, IDBLOQREQVALCARD = :IDBLOQREQVALCARD, IDBLOQLIBCAVALCARD = :IDBLOQLIBCAVALCARD, IDBLOQAPRCAVALCARD = :IDBLOQAPRCAVALCARD, IDBLOQAPMATVALCARD = :IDBLOQAPMATVALCARD, IDBLOQPREVCONVALCARD = :IDBLOQPREVCONVALCARD WHERE CDPARPLANEJA = '1' AND (EXISTS (SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMPLANEJA.CDFILIAL = CDLISTA) OR :ALLCDFILIAL = 'T')";
    
    $params = array(
      "CDNUTRRELAT1"          => $rowParamPlaneja[0]['CDNUTRRELAT1'],
      "CDNUTRRELAT2"          => $rowParamPlaneja[0]['CDNUTRRELAT2'],
      "CDNUTRRELAT3"          => $rowParamPlaneja[0]['CDNUTRRELAT3'],
      "CDNUTRRELAT4"          => $rowParamPlaneja[0]['CDNUTRRELAT4'],
      "IDBLPRCUSZER"          => $rowParamPlaneja[0]['IDBLPRCUSZER'],
      "IDCARDIAUTIL"          => $rowParamPlaneja[0]['IDCARDIAUTIL'],
      "IDCUSPADCAR"           => $rowParamPlaneja[0]['IDCUSPADCAR'],
      "IDRESTRCARD"           => $rowParamPlaneja[0]['IDRESTRCARD'],
      "IDRESTRAPROVCARD"      => $rowParamPlaneja[0]['IDRESTRAPROVCARD'],
      "IDACOMPCUSTO"          => $rowParamPlaneja[0]['IDACOMPCUSTO'],
      "IDCONSGRPRAT"          => $rowParamPlaneja[0]['IDCONSGRPRAT'],
      "IDSOMACOMEST"          => $rowParamPlaneja[0]['IDSOMACOMEST'],
      "IDCALPADCMP"           => $rowParamPlaneja[0]['IDCALPADCMP'],
      "IDCARDIFRETI"          => $rowParamPlaneja[0]['IDCARDIFRETI'],
      "VRINDCALCMP"           => $rowParamPlaneja[0]['VRINDCALCMP'],
      "CDTPRETIPADR"          => $rowParamPlaneja[0]['CDTPRETIPADR'],
      "CDTPCUSTCMP"           => $rowParamPlaneja[0]['CDTPCUSTCMP'],
      "IDPRINVENRETI"         => $rowParamPlaneja[0]['IDPRINVENRETI'],
      "IDBLOQNECCOMP"         => $rowParamPlaneja[0]['IDBLOQNECCOMP'],
      "IDSERVINCFILAGR"       => $rowParamPlaneja[0]['IDSERVINCFILAGR'],
      "IDENVMAILCARD"         => $rowParamPlaneja[0]['IDENVMAILCARD'],
      "IDUTLVALCARD"          => $rowParamPlaneja[0]['IDUTLVALCARD'],
      "IDBLOQREQVALCARD"      => $rowParamPlaneja[0]['IDBLOQREQVALCARD'],
      "IDBLOQLIBCAVALCARD"    => $rowParamPlaneja[0]['IDBLOQLIBCAVALCARD'],
      "IDBLOQAPRCAVALCARD"    => $rowParamPlaneja[0]['IDBLOQAPRCAVALCARD'],
      "IDBLOQAPMATVALCARD"    => $rowParamPlaneja[0]['IDBLOQAPMATVALCARD'],
      "IDBLOQPREVCONVALCARD"  => $rowParamPlaneja[0]['IDBLOQPREVCONVALCARD'],
      "ALLCDFILIAL"           => $allCdFilial,
      "NRLISTA"               => $nrlista
    );
    $query = $this->connection->prepare($sql);
    $query->execute($params);
    if(!empty($rowParamFilial)){
        self::selectCdfilial($request, $response, $rowParamFilial, $nrlista, $allCdFilial, $rowParamPlaneja, $params);
    }
  }
  
  public function selectCdfilial($request, $response, $rowParamFilial, $nrlista, $allCdFilial, $rowParamPlaneja, $params){
    $sql = "SELECT CDLISTA FROM LISTA WHERE NRLISTA = :NRLISTA";
    $params = array(
        "NRLISTA"   =>  $nrlista
    );
    $query  = $this->connection->prepare($sql);
    $query->execute($params);
    $filiais = $query->fetchAll();
    
    self::updateIdcomcusperc($rowParamFilial, $nrlista, $allCdFilial, $filiais);
  }
  
  public function updateIdcomcusperc($rowParamFilial, $nrlista, $allCdFilial, $filialDestino){
    $sql    = "UPDATE PARAMFILIAL SET IDCOMCUSPERC = :IDCOMCUSPERC, IDUTRETBASEINVE = :IDUTRETBASEINVE WHERE (INSTR(:CDFILIAL, CDFILIAL) <> 0 OR (:CDFILIAL = 'T')) AND ( EXISTS ( SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMFILIAL.CDFILIAL = CDLISTA ) OR :ALLCDFILIAL = 'T' )";
    $cdFilial = empty($filialDestino) ? 'T' : $filialDestino[0]['CDLISTA'];
    $params = array(
        "NRLISTA"           =>      $nrlista,
        "IDCOMCUSPERC"      =>      $rowParamFilial[0]['IDCOMCUSPERC'],
        "ALLCDFILIAL"       =>      $allCdFilial,
        "CDFILIAL"          =>      $cdFilial,
        "IDUTRETBASEINVE"   =>      $rowParamFilial[0]['IDUTRETBASEINVE']
    );
    
    $query = $this->connection->prepare($sql);
    $query->execute($params);
  }

  public function exportSafraCard($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial){
    $sql = "UPDATE PARAMPLANEJA SET IDCONSPROD = :IDCONSPROD, IDPERCCOME = :IDPERCCOME, NRCORSAFRA = :NRCORSAFRA, NRCORINICSAF = :NRCORINICSAF, NRCORENTRSAF = :NRCORENTRSAF, NRCORNUTIL = :NRCORNUTIL, NRCORNALTE = :NRCORNALTE, NRCORCARDESP = :NRCORCARDESP, NRCORCARDREV = :NRCORCARDREV, IDALTCOMCARD = :IDALTCOMCARD, VRPEMAXDIFPLAPA = :VRPEMAXDIFPLAPA, VRPEMINDIFPLAPA = :VRPEMINDIFPLAPA, CDTIPOCUSTODESC = :CDTIPOCUSTODESC, IDBLQFECHCARD = :IDBLQFECHCARD WHERE CDPARPLANEJA = '1' AND (EXISTS (SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMPLANEJA.CDFILIAL = CDLISTA) OR :ALLCDFILIAL = 'T')";
    
    $params = array(
        "IDCONSPROD"        => $rowParamPlaneja[0]['IDCONSPROD'],
        "IDPERCCOME"        => $rowParamPlaneja[0]['IDPERCCOME'],
        "NRCORSAFRA"        => $rowParamPlaneja[0]['NRCORSAFRA'],
        "NRCORINICSAF"      => $rowParamPlaneja[0]['NRCORINICSAF'],
        "NRCORENTRSAF"      => $rowParamPlaneja[0]['NRCORENTRSAF'],
        "NRCORNUTIL"        => $rowParamPlaneja[0]['NRCORNUTIL'],
        "NRCORNALTE"        => $rowParamPlaneja[0]['NRCORNALTE'],
        "NRCORCARDESP"      => $rowParamPlaneja[0]['NRCORCARDESP'],
        "NRCORCARDREV"      => $rowParamPlaneja[0]['NRCORCARDREV'],
        "IDALTCOMCARD"      => $rowParamPlaneja[0]['IDALTCOMCARD'],
        "VRPEMAXDIFPLAPA"   => $rowParamPlaneja[0]['VRPEMAXDIFPLAPA'],
        "VRPEMINDIFPLAPA"   => $rowParamPlaneja[0]['VRPEMINDIFPLAPA'],
        "CDTIPOCUSTODESC"   => $rowParamPlaneja[0]['CDTIPOCUSTODESC'],
        "IDBLQFECHCARD"     => $rowParamPlaneja[0]['IDBLQFECHCARD'],
        "ALLCDFILIAL"       => $allCdFilial,
        "NRLISTA"           => $nrlista
    );
    $query = $this->connection->prepare($sql);
    $query->execute($params);
  }
  
  public function exportElabCard($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial){
    $sql    = "UPDATE PARAMPLANEJA SET IDPERCCOME = :IDPERCCOME, CDTIPOCUSTOPLA = :CDTIPOCUSTOPLA, CDTIPOCUSTOREA = :CDTIPOCUSTOREA, IDEXIBECUSTO = :IDEXIBECUSTO WHERE CDPARPLANEJA = '1' AND (EXISTS (SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMPLANEJA.CDFILIAL = CDLISTA) OR :ALLCDFILIAL = 'T')";
    
    $params = array(
        "IDPERCCOME"        => $rowParamPlaneja[0]['IDPERCCOME'],
        "CDTIPOCUSTOPLA"    => $rowParamPlaneja[0]['CDTIPOCUSTOPLA'],
        "CDTIPOCUSTOREA"    => $rowParamPlaneja[0]['CDTIPOCUSTOREA'],
        "IDEXIBECUSTO"      => $rowParamPlaneja[0]['IDEXIBECUSTO'],
        "ALLCDFILIAL"       => $allCdFilial,
        "NRLISTA"           => $nrlista
    );
    $query = $this->connection->prepare($sql);
        $query->execute($params);
  }
  
  public function exportMensCard($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial){
    $sql = "UPDATE PARAMPLANEJA SET TXMENSCARDIA = :TXMENSCARDIA,  TXMENSCARSEM = :TXMENSCARSEM WHERE CDPARPLANEJA = '1' AND (EXISTS (SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMPLANEJA.CDFILIAL = CDLISTA) OR :ALLCDFILIAL = 'T')";
    // $sql = "SELECT CDFILIAL FROM PARAMPLANEJA WHERE CDPARPLANEJA = '1' AND (EXISTS (SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMPLANEJA.CDFILIAL = CDLISTA) OR :ALLCDFILIAL = 'T')";
    $params = array(
        "TXMENSCARDIA"  => $rowParamPlaneja[0]['TXMENSCARDIA'],
        "ALLCDFILIAL"   => $allCdFilial,
        "TXMENSCARSEM"  => $rowParamPlaneja[0]['TXMENSCARSEM'],
        "NRLISTA"       => $nrlista
    );
    
    $query = $this->connection->prepare($sql);
    $query->execute($params);
    // $result = $query->fetchAll();
    // echo json_encode($result);die;
  }

  public function exportReqRetPrato($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial){
    try {
      $sql = "UPDATE PARAMPLANEJA 
                 SET IDUTREQUPRAT = :IDUTREQUPRAT, IDRATEIORETGER = :IDRATEIORETGER, 
                     IDEXIBESALDOESTRETI = :IDEXIBESALDOESTRETI, CDTPRCONSFIX = :CDTPRCONSFIX, 
                     CDFILCONSFIX = :CDFILCONSFIX, CDPRACONSFIX = :CDPRACONSFIX, CDTPRCONSPER = :CDTPRCONSPER, 
                     CDFILCONSPER = :CDFILCONSPER, CDPRACONSPER = :CDPRACONSPER, CDTCACONSPER = :CDTCACONSPER, 
                     CDTCACONSFIX = :CDTCACONSFIX 
               WHERE CDPARPLANEJA = '1' 
                 AND (EXISTS (SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMPLANEJA.CDFILIAL = CDLISTA) OR :ALLCDFILIAL = 'T')";
    
      $params = array(
          "IDUTREQUPRAT"          => $rowParamPlaneja[0]['IDUTREQUPRAT'],
          "IDRATEIORETGER"        => $rowParamPlaneja[0]['IDRATEIORETGER'],
          "IDEXIBESALDOESTRETI"   => $rowParamPlaneja[0]['IDEXIBESALDOESTRETI'],
          "CDTPRCONSFIX"          => $rowParamPlaneja[0]['CDTPRCONSFIX'],
          "CDFILCONSFIX"          => $rowParamPlaneja[0]['CDFILCONSFIX'],
          "CDPRACONSFIX"          => $rowParamPlaneja[0]['CDPRACONSFIX'],
          "CDTPRCONSPER"          => $rowParamPlaneja[0]['CDTPRCONSPER'],
          "CDFILCONSPER"          => $rowParamPlaneja[0]['CDFILCONSPER'],
          "CDPRACONSPER"          => $rowParamPlaneja[0]['CDPRACONSPER'],
          "CDTCACONSFIX"          => $rowParamPlaneja[0]['CDTCACONSFIX'],
          "CDTCACONSPER"          => $rowParamPlaneja[0]['CDTCACONSPER'],
          "ALLCDFILIAL"           => $allCdFilial,
          "NRLISTA"               => $nrlista
      );
      
      $query = $this->connection->prepare($sql);
      $query->execute($params);
    } catch(\Exception $e) {
      if (strpos($e->getMessage(), "ORA") !== false) {
        $sql = "UPDATE PARAMPLANEJA SET IDUTREQUPRAT = :IDUTREQUPRAT, IDRATEIORETGER = :IDRATEIORETGER, IDEXIBESALDOESTRETI = :IDEXIBESALDOESTRETI, CDTPRCONSFIX = :CDTPRCONSFIX, CDFILCONSFIX = :CDFILCONSFIX, CDPRACONSFIX = :CDPRACONSFIX, CDTPRCONSPER = :CDTPRCONSPER, CDFILCONSPER = :CDFILCONSPER, CDPRACONSPER = :CDPRACONSPER WHERE CDPARPLANEJA = '1' AND (EXISTS (SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMPLANEJA.CDFILIAL = CDLISTA) OR :ALLCDFILIAL = 'T')";
    
      $params = array(
          "IDUTREQUPRAT"          => $rowParamPlaneja[0]['IDUTREQUPRAT'],
          "IDRATEIORETGER"        => $rowParamPlaneja[0]['IDRATEIORETGER'],
          "IDEXIBESALDOESTRETI"   => $rowParamPlaneja[0]['IDEXIBESALDOESTRETI'],
          "CDTPRCONSFIX"          => $rowParamPlaneja[0]['CDTPRCONSFIX'],
          "CDFILCONSFIX"          => $rowParamPlaneja[0]['CDFILCONSFIX'],
          "CDPRACONSFIX"          => $rowParamPlaneja[0]['CDPRACONSFIX'],
          "CDTPRCONSPER"          => $rowParamPlaneja[0]['CDTPRCONSPER'],
          "CDFILCONSPER"          => $rowParamPlaneja[0]['CDFILCONSPER'],
          "CDPRACONSPER"          => $rowParamPlaneja[0]['CDPRACONSPER'],
          "ALLCDFILIAL"           => $allCdFilial,
          "NRLISTA"               => $nrlista
      );
      
      $query = $this->connection->prepare($sql);
      $query->execute($params);
      }
    }
  }
  
  public function exportConfigPrato($request, $response, $nrlista, $rowParamPlaneja, $allCdFilial){
    $sql    = "UPDATE PARAMPLANEJA SET IDQTLIQUBRUT = :IDQTLIQUBRUT, IDBLOALTRELO = :IDBLOALTRELO WHERE CDPARPLANEJA = '1' AND (EXISTS (SELECT 1 FROM LISTA WHERE NRLISTA = :NRLISTA AND PARAMPLANEJA.CDFILIAL = CDLISTA) OR :ALLCDFILIAL = 'T')";
    
    $params = array(
        "IDQTLIQUBRUT"  => $rowParamPlaneja[0]['IDQTLIQUBRUT'],
        "IDBLOALTRELO"  => $rowParamPlaneja[0]['IDBLOALTRELO'],
         "ALLCDFILIAL"  => $allCdFilial,
         "NRLISTA"      => $nrlista
    );
    
    $query = $this->connection->prepare($sql);
    $query->execute($params);
  }
  
  //insere lista no banco
  public function insertLista($array) {
    $nrlista = $this->newCode->getCodeByTableName("LISTA", $this->environment->getNrOrg());
		if(gettype($array) != 'array') $array = explode("_", $array);
		$data = [];
		foreach ($array as $reg) {
			if($reg){
				$row = array(
					"NRLISTA" => $nrlista,
					"CDLISTA" => $reg,
					"__is_new" => true
				);
				array_push($data, $row);
			}
    }
    $dataSet = new DataSet("lista", $data);
    $request = new DTO\Request\DataSet($dataSet, "", "", "");
    $rowsToSave = $this->crudService->getRowsToSave($request, "lista");
    $this->crudService->save("lista", $rowsToSave);
    return $nrlista;
  }
  
  //apaga lista do banco
  public function deleteLista($nrlista) {
    $params = array(
      "NRLISTA" => $nrlista
    );
    
    $sql = "DELETE FROM LISTA WHERE NRLISTA =:NRLISTA";
    $query = $this->connection->prepare($sql);
    $query->execute($params);
  }
}


