import {
  Text, Button, Checkbox, Progress, ApexChart,
} from '@zeedhi/common';
import {
  Loader, Metadata, Http,
  IDictionary, IEventParam, I18n, dayjs as moment,
} from '@zeedhi/core';
import { Cardapio } from '../../../components/cardapio/common/Cardapio';

export class Pla00106AcompanhamentoCusto {
  private utilities = Loader.getInstance('Utilities');
  
  private elaboracaoCardapio = Loader.getInstance('Pme00600ElaboracaoCardapio');
  
  public showWindow = false;
  
  public autoUpdate = false;

  public showAttCusto = false;
  
  public chartIsVisible = false;
  
  public dateSelectedInCard = '';
  
  public get formateDateInCard() {
    if (this.dateSelectedInCard) {
      return moment(this.dateSelectedInCard, 'DD/MM/YYYY').format(this.utilities.getFormatLocale());
    }
    
    return '';
  }
  
  private planejadoDia: IDictionary = {};
  
  private custoPadrao: IDictionary = {};
  
  private custoPrato: IDictionary = {};
  
  private custoRealizado: IDictionary = {};
  
  public processDate = '';
  
  public changeVisibilityWindow() {
    this.showWindow = !this.showWindow;
    // const element = document.getElementsByTagName('body') as HTMLCollectionOf<HTMLElement>;
    // const element = document.querySelector('<body>');
    const element = document.body;
    if (this.showWindow) element?.style.setProperty('--day-column-size', '110px');
    else element?.style.setProperty('--day-column-size', '60px');
    this.closeChart();
    this.changeHeightComponentCard();
    if (this.showWindow === false) document.getElementsByClassName('container')[0].setAttribute('style', 'height: auto');
  }
  
  public initializeDtProcess() {
    this.utilities.getProcessDate('').then((processDate: string) => {
      this.processDate = processDate.substring(0, 5);
    });
  }
  
  public changeHeightComponentCard() {
    const cardapio: Cardapio = Metadata.getInstance('cardapio');
    if (this.showWindow) {
      if (cardapio.preview === 3 || cardapio.preview === 1) {
        document.getElementsByClassName('card-cont')[0].setAttribute('style', 'max-height: calc(100vh - 250px)');
      }
    } else {
      (document.getElementsByClassName('card-cont')[0] as IDictionary).style.removeProperty('max-height');
    }
  }
  
  public windowInitial({ event }: IEventParam<Button>) {
    (event as IDictionary).stopPropagation();
    if (this.utilities.checkOpenModalOverlap()) {
      if (this.elaboracaoCardapio.getFilterData.NRCARDPME !== undefined) {
        this.changeVisibilityWindow();
        if (this.showWindow) {
          this.procedureConsPlan();
        }
      } else {
        this.utilities.showAlert('withoutFilter', 'Operação bloqueada! Favor realizar o filtro.', 'error');
      }
    }
  }
  
  public autoUpdateAcomp(initialDate?: string, finalDate?: string) {
    if (this.showWindow && this.autoUpdate) this.procedureConsPlan(initialDate, finalDate);
    else if (this.showWindow) this.showAttCusto = true;
    else this.showAttCusto = false;
  }
  
  public procedureConsPlan(initialDate?: string, finalDate?: string) {
    const row = { ...this.elaboracaoCardapio.getFilterData };
    if (initialDate) {
      row.initialDate = initialDate;
      row.finalDate = (finalDate !== undefined) ? finalDate : initialDate;
    }
    this.clearAllText();
    this.changeProgress();
    Http.post('/procedureConsPlanPME', { requestType: 'Row', row }).then((response) => {
      if (response.data.dataset.consplan.length > 0) {
        this.showAttCusto = false;
        if (initialDate === undefined) document.getElementsByClassName('progAcomp')[0].scrollIntoView();
        this.makeRequestData(response.data.dataset.consplan[0]);
      }
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
      this.changeProgress();
    });
  }
  
  private makeRequestData(consplan: string) {
    this.requestAllData(consplan).then(() => {
      this.delConsPlan(consplan).then(() => {
        this.requestRealizado().then(() => {
          this.requestCustoPrato().then(() => {
            const cardapio: Cardapio = Metadata.getInstance('cardapio');
            this.custoPadrao = JSON.parse(JSON.stringify(cardapio.dates));
            this.getAllDataEvenFilter();
            this.changeProgress();
          });
        });
      });
    });
  }
  
  private requestAllData(consplan: string) {
    const filter: IDictionary = [];
    const cardFilter = this.elaboracaoCardapio.getFilterData;
    const filial = (cardFilter.aggregated?.CDFILIAL === undefined) ? null : cardFilter.aggregated.CDFILIAL;
    let filialCusto = cardFilter.cdfilcentpme;
    if (cardFilter.aggregated?.CDFILIAL !== undefined && !cardFilter.baseCost) filialCusto = cardFilter.aggregated.CDFILIAL;
    
    const referenceDate = (cardFilter.referenceDate.length > 0) ? cardFilter.referenceDate : null;
    this.utilities.onMountedFilterFind(filter, 'P_NRTIPOCUSTO', '=', cardFilter.planned);
    this.utilities.onMountedFilterFind(filter, 'P_NRCARDPME', '=', cardFilter.NRCARDPME);
    this.utilities.onMountedFilterFind(filter, 'P_DTREFECUSTO', '=', referenceDate);
    this.utilities.onMountedFilterFind(filter, 'P_NRCONSPLAN', '=', consplan);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILCENTPME', '=', cardFilter.cdfilcentpme);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIAL', '=', filial);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIALCUSTO', '=', filialCusto);
    this.utilities.onMountedFilterFind(filter, 'P_CDSERVFILI', '=', cardFilter.service.CDSERVFILI);
    this.utilities.onMountedFilterFind(filter, 'P_DTINICIAL', '=', cardFilter.initialDate);
    this.utilities.onMountedFilterFind(filter, 'P_DTFINAL', '=', cardFilter.finalDate);
    return Http.post('/find/planejadoDia', { requestType: 'FilterData', filter, limit: 10000 }).then((planejadoDia) => {
      this.planejadoDia = planejadoDia.data.data;
    });
  }
  
  public showChart() {
    const progress = Metadata.getInstance<Progress>('progressAcomp');
    if (!progress.isVisible) {
      this.chartIsVisible = true;
      this.mountCharts();
    }
  }
  
  public closeChart() {
    this.chartIsVisible = false;
    this.clearChart();
  }
  
  private clearChart() {
    const chart = Metadata.getInstance<ApexChart>('chartCusto');
    chart.series = [];
  }
  
  private mountCharts() {
    let formattedDay = '';
    const days: IDictionary = [];
    const cusPadrao: IDictionary = [];
    const cusPlan: IDictionary = [];
    const cusReal: IDictionary = [];
    const variant = {
      plan: Array<string | number>(),
      real: Array<string | number>(),
    };
    
    let acumPlan = 0;
    let acumReal = 0;
    
    let planDia: IDictionary = [];
    let realDia: IDictionary = [];
    
    let newMat = 0;
    let newCons = 0;
    let custo = 0;
    
    if (this.custoPadrao.length > 0) {
      this.custoPadrao.forEach((dayCus: IDictionary) => {
        formattedDay = moment(dayCus.DTCARDIAPME, 'DD/MM/YYYY').format(this.utilities.getFormatLocale());
        days.push(formattedDay.substring(0, 5));
        cusPadrao.push(dayCus.VRCUSPADTCAR);
        
        // Planejado
        custo = 0;
        if (this.planejadoDia.length > 0) {
          planDia = this.planejadoDia.find(
            (dia: IDictionary) => dia.DTDATA.substring(0, 5) === dayCus.DTCARDIAPME.substring(0, 5),
          );
          
          if (planDia) {
            newMat = (this.elaboracaoCardapio.getFilterData.paramfilial.IDCOMCUSPERC === 'C')
              ? this.calcValue(planDia.VRCUSTPRODMAT, planDia.QTCLIESTICAR)
              : this.calcValue(planDia.VRCUSTPRODMAT, planDia.QTCOMESTICAR);
            
            newCons = (this.elaboracaoCardapio.getFilterData.paramfilial.IDCOMCUSPERC === 'C')
              ? this.calcValue(planDia.VRCUSTOCONS, planDia.QTCLIESTICAR)
              : this.calcValue(planDia.VRCUSTOCONS, planDia.QTCOMESTICAR);
            
            custo = (newMat + newCons);
            acumPlan += (planDia.VRCUSTPRODMAT + planDia.VRCUSTOCONS);
          }
        }
        
        cusPlan.push(custo);
        
        // Realizado
        custo = 0;
        if (this.custoRealizado.length > 0) {
          realDia = this.custoRealizado.find(
            (dia: IDictionary) => dia.DTCARDIAPME.substring(0, 5) === dayCus.DTCARDIAPME.substring(0, 5),
          );
          if (realDia) {
            custo = this.calcValue(realDia.CUSTO, realDia.QTCOMEFETCAR);
            acumReal += realDia.CUSTO;
          }
        }
        cusReal.push(custo);
        
        variant.plan.push(acumPlan);
        variant.real.push(acumReal);
      });
    }
    
    this.calcChartCost(days, cusPadrao, cusPlan);
    this.calcChartCompPercapita(days, cusPadrao, cusPlan, cusReal);
    this.calcChartVariation(days, cusPadrao, variant);
    setTimeout(() => {
      this.utilities.scrollIntoElement('textAcumulado');
    }, 2);
  }
  
  private calcChartCost(days: IDictionary, cusPadrao: IDictionary, cusPlan: IDictionary) {
    const chart = Metadata.getInstance<ApexChart>('chartCusto');
    const newOptions = this.defaultChartOptions(chart, days);
    newOptions.colors = ['#DB2014', '#0A73F2'];
    chart.series = [
      {
        name: I18n.translate('Custo Padrão'),
        data: cusPadrao,
      },
      {
        name: I18n.translate('Custo Planejado'),
        data: cusPlan,
      },
    ];
    chart.updateChart(newOptions);
  }
  
  private calcChartCompPercapita(days: IDictionary, cusPadrao: IDictionary, cusPlan: IDictionary, cusReal: IDictionary) {
    const chart = Metadata.getInstance<ApexChart>('chartComparacaoPercapita');
    const newOptions = this.defaultChartOptions(chart, days);
    newOptions.colors = ['#DB2014', '#0A73F2', '#22DB16'];
    chart.series = [
      {
        name: I18n.translate('Custo Padrão'),
        type: 'line',
        data: cusPadrao,
      },
      {
        name: I18n.translate('Custo Planejado'),
        type: 'bar',
        data: cusPlan,
      },
      {
        name: I18n.translate('Custo Realizado'),
        type: 'line',
        data: cusReal,
      },
    ];
    chart.updateChart(newOptions);
  }
  
  private calcChartVariation(days: IDictionary, cusPadrao: IDictionary, variant: IDictionary) {
    const chart = Metadata.getInstance<ApexChart>('chartVariation');
    const newOptions = this.defaultChartOptions(chart, days);
    newOptions.colors = ['#DB2014', '#0A73F2', '#22DB16'];
    chart.series = [
      {
        name: I18n.translate('Custo Padrão'),
        type: 'line',
        data: cusPadrao,
      },
      {
        name: I18n.translate('Custo Planejado'),
        data: variant.plan,
      },
      {
        name: I18n.translate('Custo Realizado'),
        data: variant.real,
      },
    ];
    chart.updateChart(newOptions);
  }
  
  private defaultChartOptions(chart: ApexChart, days: IDictionary) {
    const newOptions = chart.options;
    newOptions.xaxis = {
      type: 'string',
      categories: days,
    };
    newOptions.yaxis = {
      labels: {
        formatter: (value: number) => {
          const language = (this.utilities.getLanguage() as string)?.replace('_', '-') as string;
          return value.toLocaleString(language, { minimumFractionDigits: 5 });
        },
      },
    };
    newOptions.annotations.xaxis[0].x = this.processDate;
    return newOptions;
  }
  
  private delConsPlan(consplan: string) {
    const row = { ...this.elaboracaoCardapio.getFilterData };
    row.CONSPLAN = consplan;
    return Http.post('/deleteConsPlan', { requestType: 'Row', row }).then((response) => {
      const hasExclude = response.data.dataset.hasExclude[0];
      return hasExclude;
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
    });
  }
  
  private requestRealizado() {
    const filter: IDictionary = [];
    const cardFilter = this.elaboracaoCardapio.getFilterData;
    const filial = (cardFilter.aggregated?.CDFILIAL === undefined) ? null : cardFilter.aggregated.CDFILIAL;
    
    let filialCusto = cardFilter.cdfilcentpme;
    if (cardFilter.aggregated?.CDFILIAL !== undefined && !cardFilter.baseCost) filialCusto = cardFilter.aggregated.CDFILIAL;
    
    const referenceDate = (cardFilter.referenceDate.length > 0) ? cardFilter.referenceDate : null;
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIAL', '=', filial);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIALCUSTO', '=', filialCusto);
    this.utilities.onMountedFilterFind(filter, 'P_DTINI', '=', cardFilter.initialDate);
    this.utilities.onMountedFilterFind(filter, 'P_NRTIPOCUSTO', '=', cardFilter.planned);
    this.utilities.onMountedFilterFind(filter, 'P_DTREFECUSTO', '=', referenceDate);
    this.utilities.onMountedFilterFind(filter, 'P_CDSERVFILI', '=', cardFilter.service.CDSERVFILI);
    this.utilities.onMountedFilterFind(filter, 'P_DTFIN', '=', cardFilter.finalDate);
    return Http.post('/find/custoRealizado', { requestType: 'FilterData', filter, limit: 10000 }).then((custoRealizado) => {
      this.custoRealizado = custoRealizado.data.data;
    });
  }
  
  private requestCustoPrato() {
    const filter: IDictionary = [];
    const filial = (this.elaboracaoCardapio.getFilterData.aggregated?.CDFILIAL === undefined)
      ? this.elaboracaoCardapio.getFilterData.cdfilcentpme : this.elaboracaoCardapio.getFilterData.aggregated.CDFILIAL;
    const referenceDate = (this.elaboracaoCardapio.getFilterData.referenceDate.length > 0)
      ? this.elaboracaoCardapio.getFilterData.referenceDate : null;
    const baseCost = this.elaboracaoCardapio.getFilterData.baseCost;
    const filialBasedCost = (baseCost) ? this.elaboracaoCardapio.getFilterData.cdfilcentpme : filial;
    
    this.utilities.onMountedFilterFind(filter, 'P_CDFILIAL', '=', filial);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILICUSTO', '=', filialBasedCost);
    this.utilities.onMountedFilterFind(filter, 'P_NRTIPOCUSTO', '=', this.elaboracaoCardapio.getFilterData.planned);
    this.utilities.onMountedFilterFind(filter, 'P_NRCARDPME', '=', this.elaboracaoCardapio.getFilterData.NRCARDPME);
    this.utilities.onMountedFilterFind(filter, 'P_CDFILCENTPME', '=', this.elaboracaoCardapio.getFilterData.cdfilcentpme);
    this.utilities.onMountedFilterFind(
      filter, 'P_CDSERVFILI', '=', this.elaboracaoCardapio.getFilterData.service.CDSERVFILI,
    );
    this.utilities.onMountedFilterFind(filter, 'P_DTINICIAL', '=', this.elaboracaoCardapio.getFilterData.initialDate);
    this.utilities.onMountedFilterFind(
      filter, 'P_CDTIPOCARD', '=', this.elaboracaoCardapio.getFilterData.typeMenu.CDTIPOCARD,
    );
    this.utilities.onMountedFilterFind(filter, 'P_DTFINAL', '=', this.elaboracaoCardapio.getFilterData.finalDate);
    this.utilities.onMountedFilterFind(filter, 'P_DTREFERENCIA', '=', referenceDate);
    return Http.post('/find/custoPrato', { requestType: 'FilterData', filter, limit: 1000000 }).then((custoPrato) => {
      this.custoPrato = custoPrato.data.data;
    });
  }
  
  public getAllDataEvenFilter(dateCard: string = '') {
    const cardapio: Cardapio = Metadata.getInstance('cardapio');
    let date = cardapio.getCurrentSelectedRegister()?.DTCARDIAPME.substring(0, 10);
    if (dateCard) date = dateCard.substring(0, 10);
    // this.dateSelectedInCard = moment(date, 'DD/MM/YYYY').format(this.utilities.getFormatLocale());
    this.dateSelectedInCard = date;
    const filterPlanDia = this.planejadoDia.find((dia: IDictionary) => dia.DTDATA.substring(0, 10) === date);
    const filterRealDia = this.custoRealizado.find((dia: IDictionary) => dia.DTCARDIAPME.substring(0, 10) === date);
    const totalMonths = this.totalMonths();
    const totalMonthsReal = this.totalMonthsReal();
    const acumulado = this.totalMonths(this.dateSelectedInCard);
    this.setAllTextData(filterPlanDia, filterRealDia, totalMonths, acumulado, totalMonthsReal);
  }
  
  private totalMonths(hasDate?: string): IDictionary {
    const copyPlanDia = JSON.parse(JSON.stringify(this.planejadoDia));
    const totalMonths: IDictionary = {};
    totalMonths.VRCUSTPRODMAT = 0; totalMonths.VRCUSTOCONS = 0; totalMonths.CUSTO = 0;
    totalMonths.PADRAO = 0; totalMonths.COMENSAIS = 0;
    
    if (hasDate === undefined) {
      this.allDays(totalMonths, copyPlanDia);
      totalMonths.CUSTO = totalMonths.VRCUSTPRODMAT + totalMonths.VRCUSTOCONS;
      totalMonths.SALDO = totalMonths.PADRAO - totalMonths.CUSTO;
    } else {
      this.upSelectedData(totalMonths, copyPlanDia);
    }
    
    return totalMonths;
  }
  
  // Soma os dados ate a data selecionada
  private upSelectedData(totalMonths: IDictionary, copyPlanDia: IDictionary) {
    Object.keys(copyPlanDia).forEach((dia: string) => {
      if (copyPlanDia[dia].DTDATA.substring(0, 10) <= this.dateSelectedInCard) {
        totalMonths.VRCUSTPRODMAT += copyPlanDia[dia].VRCUSTPRODMAT;
        totalMonths.VRCUSTOCONS += copyPlanDia[dia].VRCUSTOCONS;
        totalMonths.COMENSAIS += (this.elaboracaoCardapio.getFilterData.paramfilial.IDCOMCUSPERC === 'C')
          ? copyPlanDia[dia].QTCLIESTICAR : copyPlanDia[dia].QTCOMESTICAR;
      }
    });
  }
  
  // Soma os dados de todos os dias.
  private allDays(totalMonths: IDictionary, copyPlanDia: IDictionary) {
    let comensais;
    Object.keys(copyPlanDia).forEach((dia: string) => {
      totalMonths.VRCUSTPRODMAT += copyPlanDia[dia].VRCUSTPRODMAT;
      comensais = (this.elaboracaoCardapio.getFilterData.paramfilial.IDCOMCUSPERC === 'C')
        ? copyPlanDia[dia].QTCLIESTICAR : copyPlanDia[dia].QTCOMESTICAR;
      totalMonths.VRCUSTOCONS += copyPlanDia[dia].VRCUSTOCONS;
      totalMonths.COMENSAIS += comensais;

      totalMonths.PADRAO += (this.custoPadrao.length > 0 && dia < this.custoPadrao.length)
        ? this.custoPadrao[dia].VRCUSPADTCAR * comensais : 0;
    });
  }
  
  private totalMonthsReal(): IDictionary {
    const copyRealDia = JSON.parse(JSON.stringify(this.custoRealizado));
    const totalMonthsReal: IDictionary = {};
    totalMonthsReal.CUSTO = 0; totalMonthsReal.QTCOMEFETCAR = 0;
    
    this.upSelectDataReal(totalMonthsReal, copyRealDia);
    
    return totalMonthsReal;
  }
  
  // Soma os dados ate a data selecionada
  private upSelectDataReal(totalMonthsReal: IDictionary, copyRealDia: IDictionary) {
    Object.keys(copyRealDia).forEach((dia: string) => {
      if (copyRealDia[dia].DTCARDIAPME.substring(0, 10) <= this.dateSelectedInCard) {
        totalMonthsReal.CUSTO += copyRealDia[dia].CUSTO;
        totalMonthsReal.QTCOMEFETCAR += copyRealDia[dia].QTCOMEFETCAR;
      }
    });
  }
  
  private setAllTextData(
    planDia: IDictionary, filterRealDia: IDictionary, totalMonths: IDictionary,
    acumulado: IDictionary, totalMonthsReal: IDictionary,
  ) {
    this.setTextPlanDia(planDia, filterRealDia);
    this.setTextPerCapita(planDia);
    this.setTotalMes(totalMonths);
    this.setTextAcumulado(filterRealDia, acumulado, totalMonthsReal);
  }
  
  // PLANEJAMENTO DO DIA
  private setTextPlanDia(planDia: IDictionary, filterRealDia: IDictionary) {
    if (planDia) {
      Metadata.getInstance<Text>('valueMateriaPlan').text = this.utilities.formatValues(planDia.VRCUSTPRODMAT, 5);
      Metadata.getInstance<Text>('valueConsumoPlan').text = this.utilities.formatValues(planDia.VRCUSTOCONS, 5);
      Metadata.getInstance<Text>('valueCustoTotalPlan').text = this.utilities.formatValues(
        (planDia.VRCUSTPRODMAT + planDia.VRCUSTOCONS), 5,
      );
    }
    
    // REALIZADO
    const valueCustTotalPlan = Metadata.getInstance<Text>('valueCustoTotalPlan2');
    if (filterRealDia) {
      valueCustTotalPlan.text = this.utilities.formatValues(filterRealDia.CUSTO, 5);
    } else valueCustTotalPlan.text = this.utilities.formatValues(0, 5);
  }
  
  // PER CAPITA DO DIA
  private setTextPerCapita(planDia: IDictionary) {
    const newMat = (this.elaboracaoCardapio.getFilterData.paramfilial.IDCOMCUSPERC === 'C')
      ? this.calcValue(planDia?.VRCUSTPRODMAT, planDia?.QTCLIESTICAR)
      : this.calcValue(planDia?.VRCUSTPRODMAT, planDia?.QTCOMESTICAR);
    
    const newCons = (this.elaboracaoCardapio.getFilterData.paramfilial.IDCOMCUSPERC === 'C')
      ? this.calcValue(planDia?.VRCUSTOCONS, planDia?.QTCLIESTICAR)
      : this.calcValue(planDia?.VRCUSTOCONS, planDia?.QTCOMESTICAR);
    
    const custo = (newMat + newCons);
    const saldo = (this.getCustPadraoSelected() - custo);
    Metadata.getInstance<Text>('valueMateria').text = this.utilities.formatValues(newMat, 5);
    Metadata.getInstance<Text>('valueConsumo').text = this.utilities.formatValues(newCons, 5);
    Metadata.getInstance<Text>('valueCusto').text = this.utilities.formatValues(custo, 5);
    Metadata.getInstance<Text>('valuePadrao').text = this.utilities.formatValues(this.getCustPadraoSelected(), 5);
    Metadata.getInstance<Text>('valueSaldo').text = this.utilities.formatValues(saldo, 5);
    if (saldo < 0) document.getElementsByName('valueSaldo')[0].style.color = 'red';
    else document.getElementsByName('valueSaldo')[0].style.color = 'var(--zd-font-color)';
  }
  
  // PER CAPITA DO DIA TOTAL MES
  private setTotalMes(totalMonths: IDictionary) {
    Metadata.getInstance<Text>('valueMateria2').text = this.utilities.formatValues(totalMonths.VRCUSTPRODMAT, 5);
    Metadata.getInstance<Text>('valueConsumo2').text = this.utilities.formatValues(totalMonths.VRCUSTOCONS, 5);
    Metadata.getInstance<Text>('valueCusto2').text = this.utilities.formatValues(totalMonths.CUSTO, 5);
    Metadata.getInstance<Text>('valuePadrao2').text = this.utilities.formatValues(totalMonths.PADRAO, 5);
    Metadata.getInstance<Text>('valueSaldo2').text = this.utilities.formatValues(totalMonths.SALDO, 5);
    if (totalMonths.SALDO < 0) document.getElementsByName('valueSaldo2')[0].style.color = 'red';
    else document.getElementsByName('valueSaldo2')[0].style.color = 'var(--zd-font-color)';
  }
  
  // ACUMULADO ATÉ
  private setTextAcumulado(filterRealDia: IDictionary, acumulado: IDictionary, totalMonthsReal: IDictionary) {
    const custoTotal = acumulado.VRCUSTPRODMAT + acumulado.VRCUSTOCONS;
    Metadata.getInstance<Text>('valueMateriaAcu').text = this.utilities.formatValues(acumulado.VRCUSTPRODMAT, 5);
    Metadata.getInstance<Text>('valueConsumoAcu').text = this.utilities.formatValues(acumulado.VRCUSTOCONS, 5);
    Metadata.getInstance<Text>('valueCustoTotalAcu').text = this.utilities.formatValues(custoTotal, 5);
    Metadata.getInstance<Text>('valueComensaisAcu').text = this.utilities.formatValues(acumulado.COMENSAIS, 5);
    Metadata.getInstance<Text>('valuePCMAcu').text = this.utilities.formatValues(
      this.calcValue(custoTotal, acumulado.COMENSAIS), 5,
    );
    
    // REALIZADO
    const pcm = (totalMonthsReal.QTCOMEFETCAR === 0) ? 0 : totalMonthsReal.CUSTO / totalMonthsReal.QTCOMEFETCAR;
    
    if (this.custoRealizado.length > 0) {
      // Soma de CUSTO até a data posicionada
      Metadata.getInstance<Text>('valueCustoTotalAcu2').text = this.utilities.formatValues(totalMonthsReal.CUSTO, 5);
      // Soma de QTCOMEFETCAR até a data posicionada
      Metadata.getInstance<Text>('valueComensaisAcu2').text = this.utilities.formatValues(totalMonthsReal.QTCOMEFETCAR, 5);
      // Custo total / comensais somado
      Metadata.getInstance<Text>('valuePCMAcu2').text = this.utilities.formatValues(pcm, 5);
    }
  }
  
  private clearAllText() {
    const val = this.utilities.formatValues(0, 5);
    Metadata.getInstance<Text>('valueMateriaPlan').text = val;
    Metadata.getInstance<Text>('valueConsumoPlan').text = val;
    Metadata.getInstance<Text>('valueCustoTotalPlan').text = val;
    Metadata.getInstance<Text>('valueMateria').text = val;
    Metadata.getInstance<Text>('valueConsumo').text = val;
    Metadata.getInstance<Text>('valueCusto').text = val;
    Metadata.getInstance<Text>('valuePadrao').text = val;
    Metadata.getInstance<Text>('valueSaldo').text = val;
    Metadata.getInstance<Text>('valueMateria2').text = val;
    Metadata.getInstance<Text>('valueConsumo2').text = val;
    Metadata.getInstance<Text>('valueCusto2').text = val;
    Metadata.getInstance<Text>('valuePadrao2').text = val;
    Metadata.getInstance<Text>('valueSaldo2').text = val;
    Metadata.getInstance<Text>('valueMateriaAcu').text = val;
    Metadata.getInstance<Text>('valueConsumoAcu').text = val;
    Metadata.getInstance<Text>('valueCustoTotalAcu').text = val;
    Metadata.getInstance<Text>('valueComensaisAcu').text = val;
    Metadata.getInstance<Text>('valuePCMAcu').text = val;
    Metadata.getInstance<Text>('valueCustoTotalAcu2').text = val;
    Metadata.getInstance<Text>('valueComensaisAcu2').text = val;
    Metadata.getInstance<Text>('valuePCMAcu2').text = val;
    Metadata.getInstance<Text>('valueCustoTotalPlan2').text = val;
  }
  
  private calcValue(vrCust: number, qt: number): number {
    if (vrCust && qt) {
      if (vrCust > 0 && qt > 0) return (vrCust / qt);
      return vrCust;
    }
    
    return 0;
  }
  
  private calcValuePCM(vrCust: number, qt: number): number {
    if (vrCust > 0 && qt > 0) return (vrCust / qt);
    return vrCust;
  }
  
  private getCustPadraoSelected(): number {
    if (this.custoPadrao.length > 0) {
      const custo = this.custoPadrao.find(
        (dia: IDictionary) => dia.DTCARDIAPME.substring(0, 10) === this.dateSelectedInCard,
      );
      if (custo) return custo.VRCUSPADTCAR;
    }
    return 0;
  }
  
  public controllReloadDisable({ component }: IEventParam<Checkbox>) {
    const reload = Metadata.getInstance<Button>('reloadCusto');
    reload.disabled = !reload.disabled;
    this.autoUpdate = component.value;
  }
  
  public reload() {
    this.closeChart();
    this.procedureConsPlan();
  }
  
  public changeProgress() {
    const progress = Metadata.getInstance<Progress>('progressAcomp');
    progress.isVisible = !progress.isVisible;
  }
}
