import {
  Metadata, Http, Loader, IEventParam, IDictionary, dayjs as moment,
} from '@zeedhi/core';

import {
  Select, SelectMultiple, Form, Modal, ModalService, DialogService, LoadingService,
} from '@zeedhi/common';

export class Pme00510AtualizarComensaisCardController {
  public appController = Loader.getInstance('AppController');
  
  public modalController = Loader.getInstance('ModalController');
  
  public utilities = Loader.getInstance('Utilities');
  
  public gridEditController = Loader.getInstance('GridEditableController');
  
  public dataProcessamentoDe?: string = '';
  
  public dataProcessamentoAte?: string = '';
  
  public dtProcessa?: string = '';
  
  private modalConfigCard!: Modal;
  
  public async createPeriodoModal() {
    this.modalController.createModal('pme/parametrizacao/modals/formAtualizarComensais');
    this.modalConfigCard = await ModalService.createFromJsonPost('', { jsonPath: 'modals/closeButtonModal' });
  }
  
  public destroyPeriodoModal() {
    this.modalController.destroyModal();
  }
  
  public cancelModal() {
    this.modalConfigCard.hide();
    this.modalConfigCard.destroy();
    this.modalController.closeModal();
    const unidade = Metadata.getInstance<Select>('UNIDADE');
    const cardapio = Metadata.getInstance<Select>('TIPOCARD');
    const servico = Metadata.getInstance<Select>('SERVICO');
    unidade.setValue('');
    cardapio.setValue('');
    servico.setValue('');
  }
  
  public openModalAtualizaComensais() {
    if (this.utilities.centralIsValid()) {
      this.modalController.openModal();
      this.dataProcessamentoDe = this.dtProcessa;
      this.dataProcessamentoAte = this.dtProcessa;
    }
  }
  
  public async getDtProcessa() {
    this.dtProcessa = await this.utilities.getProcessDate();
    this.utilities.centralIsValid();
  }
  
  public setFilterUnidade({ component }: IEventParam<Select>) {
    const conditions = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  }
  
  public setFilterTpCardapio({ component }: IEventParam<SelectMultiple>) {
    const filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'NRPASTATCARD',
        operator: '=',
        value: null,
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  }
  
  public setFilterServ({ component }: IEventParam<SelectMultiple>) {
    const unidade = Metadata.getInstance<Select>('UNIDADE');
    const tipocard = Metadata.getInstance<Select>('TIPOCARD');

    let tipoCard = 'T';
    let cdfilial = 'T';

    if (unidade.value.length > 0) cdfilial = unidade.value.join('_');
    if (tipocard.value.length > 0) tipoCard = tipocard.value.join('_');

    const filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: tipoCard,
      },
      {
        name: 'CDFILIAL',
        operator: '=',
        value: cdfilial,
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  }
  
  public exportStoresDiners() {
    const form: Form = Metadata.getInstance('form');
    const row = form.value;
    row.CDFILCENTPME = this.appController.getCdCentral();
    row.DTPROC = this.dtProcessa;
    if (this.validateDate(form)) {
      DialogService.show({
        name: 'confirmUpdate',
        type: 'warning',
        title: 'Atenção',
        text: 'Deseja atualizar os comensais nos cardápios contemplados pelo período?',
        buttons: [
          {
            name: 'progressLine',
            component: 'ZdProgress',
            label: 'Progress',
            indeterminate: true,
            cssClass: 'loading-progress-line',
          },
          {
            name: 'sim',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.confirmUpdate(row) },
            outline: true,
          },
          {
            name: 'nao',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
        ],
      });
    }
  }
  
  private confirmUpdate(row: IDictionary) {
    // const buttonYes = Metadata.getInstance<Button>('sim');
    LoadingService.show(' ');
    Http.post('/buscaComensaisUnidade', { requestType: 'Row', row }).then(() => {
      Http.post('/buscaTotalCentral', { requestType: 'Row', row }).then(() => {
        this.utilities.showAlert('Alert', 'Cardápio atualizado com sucesso!', 'success');
        DialogService.hide();
      }).finally(() => {
        LoadingService.hide();
      });
    });
  }
  
  private validateDate(form: Form) {
    let valid = false;
    const row: IDictionary = form.value;
    const periodoDe = row.PERIODODE;
    const periodoAte = row.PERIODOATE;
    if (moment(moment(periodoDe).format('L')) < moment(moment(this.dtProcessa).format('L'))) {
      this.utilities.showAlert('alertError', 'Data inicial menor que a data de processamento.', 'error');
    } else if (form.validate()) {
      if (this.utilities.dateIsValid(periodoDe, periodoAte)) valid = true;
      else this.utilities.showAlert('alertError', 'Data Inicial deve ser menor que a data final.', 'error');
    }
    return valid;
  }

  public clearFieldServ() {
    const servico = Metadata.getInstance<Select>('SERVICO');
    servico.setValue([]);
  }
}
