import {
  Http, IDictionary, IEventParam, Loader, Metadata, Config, Datasource,
} from '@zeedhi/core';
import {
  Button, Column, DialogService, Form, GridEditable, Select, SelectMultiple, TextInput, Card, LoadingService,
} from '@zeedhi/common';
import { PmeMask } from '@/config';
  
export class Pme00200ServicoController {
  private utilities = Loader.getInstance('Utilities');
  
  public crudController = Loader.getInstance('CrudController');
  
  public appController = Loader.getInstance('AppController');

  public gridEditController = Loader.getInstance('GridEditableController');
  
  public modalController = Loader.getInstance('ModalController');

  public editable = false;

  public activeArv: object | undefined;

  public selectedServ?: string = '';

  public selectedNmServ?: string = '';
  
  public unidade?: string = '';
  
  public checkedRowsServ: IDictionary = {};
  
  public checkedRowsTipo: IDictionary = {};
  
  public currentRowCopy: IDictionary = {};
  
  public nrseqconfcard = 0;

  public showConfig = false;

  public showTipoPrat = false;

  public colsServ = 12;

  private isCentral = false;
  
  private detailIsVisible = false;
  
  private maxNrOrd = 0;
  
  // public cdUnidadeServicoDetail = '';
  
  private cdGrupServ = '';
  
  private gridConfEditing = true;
  
  public get colsConfigServ() {
    return this.colsServ % 12;
  }
  
  public returnConditionsUnidade(nameFilter: string) {
    const unidSelecionada = Metadata.getInstance<Select>('UNIDADE');
    const conditions = [
      {
        name: nameFilter,
        operator: '=',
        value: unidSelecionada.value.CDFILIAL,
      },
    ];
    return conditions;
  }
  
  public fillCode({ component }: IEventParam<TextInput>) {
    if (component.name === 'CDGRUPSERV_editable_') component.value = component.value.padStart(3, '0');
    else component.value = component.value.padStart(5, '0');
  }
  
  public addRow({ component }: IDictionary) {
    this.editable = true;
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;

    if (!this.gridEditController.newRow) {
      if (grid.name === 'SERVICOS') {
        const item = { __is_new: true };
        grid.datasource.data.unshift(item);
      }
      this.gridEditController.newRow = true;
      grid.editing = true;
      if (!this.gridEditController.isInlineEditing) this.gridEditController.onInlineEdit({ component: grid });
    }
  }

  public cancelEditing({ component }: IDictionary) {
    const buttonCancel = Metadata.getInstance<Button>('cancelButtonConf');
    const buttonSave = Metadata.getInstance<Button>('saveButtonConf');
    const grid = this.utilities.returnGrid(component) as GridEditable;
    this.editable = false;
    if (grid.name === 'CONFIGTIPOPRAT_SERV') {
      this.gridEditController.defaultState(grid);
      buttonCancel.disabled = true;
      buttonSave.disabled = true;
      this.gridConfEditing = false;
      this.changeCurrentConf({ component: grid.datasource });
    } else this.gridEditController.cancelEditing({ component });
    
    this.resetTipoPrat();
  }
  
  public cancelEditingGridServ({ component }: IDictionary) {
    this.editable = false;
    const gridServ = this.utilities.returnGrid(component) as GridEditable;
    if (gridServ.editing) {
      this.gridEditController.newRow = false;
      // gridServ.cancelEditedRows();
      
      this.gridEditController.cancelEditedRows({ component: gridServ });
      gridServ.datasource.currentRow = {};
      gridServ.datasource.get();
    }
  }
  
  // seta primeira linha do grid servicos como sendo a current row
  private setCurrentRowGridServ() {
    const gridServ = Metadata.getInstance<GridEditable>('SERVICOS');
    gridServ.datasource.get().then(() => {
      const data = gridServ.datasource.data;
      if (data.length > 0) {
        gridServ.datasource.currentRow = data[0];
        // this.setServ(gridServ.datasource.currentRow);
      }
    });
  }
  
  public reloadGridServicos() {
    this.setCurrentRowGridServ();
  }
  
  public clickRowGrid() {
    const gridServ = Metadata.getInstance<GridEditable>('SERVICOS');
    if (!gridServ.editing) {
      // const row = component.currentRow;
      // this.setServ(row);
      this.filterGridConfPrat();
    } else {
      this.showConfig = false;
      this.colsServ = 12;
    }
  }
  
  // Filtro
  public setFilterGridService({ component }: IEventParam<Select>) {
    const gridServ = Metadata.getInstance<GridEditable>('SERVICOS');
    const cdfilial = component.value;
    const addButton = Metadata.getInstance<Button>('addButton');
    const exportButton = Metadata.getInstance<Button>('exportButton');
    const reloadButton = Metadata.getInstance<Button>('reloadButton');
    this.isCentral = (cdfilial !== null && cdfilial.IDFILCENTPME === 'S');

    if ((cdfilial === null) || (cdfilial && cdfilial.IDFILCENTPME !== 'S' && cdfilial.CENTRAL === null)) {
      if (cdfilial && cdfilial.IDFILCENTPME !== 'S' && cdfilial.CENTRAL === null) {
        this.utilities.showAlert(
          'alertError',
          'Unidade não está ligada a uma central de alimentação escolar. O cadastro deve ser realizado na matriz.',
          'error',
        );
      }
      gridServ.datasource.filter = [
        {
          name: 'P_CDFILIAL',
          operator: '=',
          value: '',
        },
      ];
      gridServ.datasource.get().then(() => {
        exportButton.disabled = true;
        addButton.disabled = true;
        reloadButton.disabled = true;
        gridServ.selectedRows = [];
      });
    } else {
      gridServ.datasource.filter = [
        {
          name: 'P_CDFILIAL',
          operator: '=',
          value: cdfilial.CDFILIAL,
        },
      ];
      gridServ.datasource.get().then(() => {
        if (cdfilial.CDFILIAL) {
          addButton.disabled = false;
          reloadButton.disabled = false;
          const data = gridServ.datasource.data;
          if (data.length === 0) gridServ.datasource.currentRow = {};

          // this.setServ(gridServ.datasource.currentRow);

          if (cdfilial.IDFILCENTPME === 'S' && cdfilial.IDTPFILIALCENT === 'M') exportButton.disabled = false;
          else exportButton.disabled = true;
        } else {
          addButton.disabled = true;
          exportButton.disabled = true;
          reloadButton.disabled = true;
        }
      }).finally(() => {
        this.colsServ = 12;
        this.showConfig = false;
        gridServ.selectedRows = [];
        // this.returnDadosPadraoServ({ component: gridServ });
      });
    }
  }
  
  public setDataModalExport() {
    const formUnidade = Metadata.getInstance<Form>('formUnidade');
    const unidade = formUnidade.value.UNIDADE;
    const unidExport = Metadata.getInstance<Select>('UNIDADE_EXPORT');
    const unidAgregada = Metadata.getInstance<Select>('UNIDADEAGREG');
    const serviceExport = Metadata.getInstance<Select>('SERVICO_EXPORT');
    unidExport.datasource.data = [unidade];
    unidExport.setValue(unidade);
    unidAgregada.datasource.filter = this.returnConditionsUnidade('CDFILCENTPME');
    unidAgregada.datasource.get();
    serviceExport.datasource.filter = this.returnConditionsUnidade('CDFILIAL');
    serviceExport.datasource.get();
  }
  
  // Aba de Serviços(Grid)
  public filterServ({ component }: IEventParam<Select>) {
    const cdfilcentpme = this.appController.getCdCentral();
    const conditions = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: cdfilcentpme,
      },
    ];
    component.datasource.filter = conditions;
    component.datasource.get();
  }
  
  public filterProd({ component }: IEventParam<Select>) {
    component.datasource.get();
  }
  
  public saveService({ component }: IDictionary) {
    // const form = Metadata.getInstance<Form>('formServico');
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    const rows: IDictionary = grid.getEditedRows(false, true);
    const exportButton = Metadata.getInstance<Button>('exportButton');
    
    if (grid.isGridValid(true)) {
      if (rows.length > 0) {
        const cdfilial = Metadata.getInstance<Select>('UNIDADE').value.CDFILIAL;
        let rowsInvalid = false;
        
        rows.forEach((e: IDictionary) => {
          if (this.validateFieldsHour(e.HRINICSERV, e.HRFINASERV, e.HRINICATEN)) {
            e.CDSERVFILI = e.CDSERVFILI ? e.CDSERVFILI.padStart(5, '0') : e.SERVICO.CDSERVPADR;
            e.HRINICATEN = e.HRINICATEN ? this.formatHrToSave(e.HRINICATEN) : null;
            e.HRINICSERV = e.HRINICSERV && e.HRFINASERV ? this.formatHrToSave(e.HRINICSERV) : null;
            e.HRFINASERV = e.HRFINASERV && e.HRINICSERV ? this.formatHrToSave(e.HRFINASERV) : null;
            e.CDGRUPSERV = e.CDGRUPSERV ? e.CDGRUPSERV : null;
            e.NMSERVICO = e.NMSERVICO ? e.NMSERVICO : e.SERVICO.NMSERVPADR;
            e.CDPRODUTO = e.CDPRODUTO ? e.CDPRODUTO : e.PRODUTO.CDPRODUTO;
            e.CDFILIAL = cdfilial;
            e.CDFILCENTPME = this.appController.getCdCentral();
            e.CDROTATRANS = e.CDROTATRANS ? e.CDROTATRANS : null;
          } else {
            rowsInvalid = true;
            // break;
          }
        });
        if (!rowsInvalid) {
          if (grid) LoadingService.show(' ');
  
          Http.post('/saveServ', { requestType: 'DataSet', rows }).then((response) => {
            // const result = response.data;
            if (response.data.dataset !== undefined) {
              const result = response.data.dataset.result;
              // const gridServicoDetail: GridEditable = Metadata.getInstance('SERVICOS');
              if (exportButton.disabled === false) Http.post('/saveAgregada', { requestType: 'Row', rows });
              this.utilities.showAlert('alertError', result.message, result.type);
              this.gridEditController.defaultState(grid);
              // gridServicoDetail.datasource.get();
            } else if (response.data.error) {
              const error = response.data.error;
              if (error.includes('ORA-00001')) {
                this.utilities.showAlert('alert', 'Impossível adicionar. Registro já existe.', 'error');
              } else this.utilities.showAlert('alertError', error, 'error');
            }
          }).catch((error) => {
            if (error.includes('ORA-00001')) {
              this.utilities.showAlert('alert', 'Impossível adicionar. Registro já existe.', 'error');
            } else this.utilities.showAlert('alertError', error, 'error');
          }).finally(() => {
            if (grid) LoadingService.hide();
          });
        }
      } else {
        this.gridEditController.defaultState(grid);
        this.utilities.showAlert('alert', 'Nenhum registro editado.', 'yellow');
      }
    }
  }
  
  public validateFieldsHour(hourIni: string, hourFin: string, hourAten: string) {
    let valid = true;
    if (hourIni && hourIni !== '' && hourFin && hourFin !== '') {
      const hrIni = hourIni.split(':');
      const secondsIni = (+hrIni[0]) * 60 * 60 + (+hrIni[1]) * 60;
      const hrFin = hourFin.split(':');
      const secondsFin = (+hrFin[0]) * 60 * 60 + (+hrFin[1]) * 60;
      
      if (!this.utilities.timeIsValid(hourIni) || !this.utilities.timeIsValid(hourFin)
          || !this.utilities.timeIsValid(hourAten)
      ) {
        this.utilities.showAlert('alertHour', 'Hora Inválida.', 'warning');
        valid = false;
      } else if (secondsIni > secondsFin) {
        this.utilities.showAlert('alertError',
          "Horário de 'Servido de' não pode ser maior que o horário de 'Até'", 'error');
        valid = false;
      }
    } else if (!this.utilities.timeIsValid(hourAten)) {
      this.utilities.showAlert('alertHour', 'Hora Inválida.', 'warning');
      valid = false;
    }
    return valid;
  }
  
  public formatHrToSave(hour: string) {
    return hour.replace(':', '');
  }
  
  public confirmDeleteServ({ component }: IDictionary) {
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    this.checkedRowsServ = grid.selectedRows;
    if (this.checkedRowsServ.length === 0) this.utilities.showAlert('alert', 'Nenhum registro selecionado.', 'warning');
    else {
      DialogService.show({
        name: 'pma00200_excluiServico',
        type: 'warning',
        title: 'Atenção',
        text: 'Deseja excluir os registros?',
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.deleteServ(this.checkedRowsServ, grid) },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
          {
            name: 'progressLine',
            component: 'ZdProgress',
            label: 'Progress',
            indeterminate: true,
            cssClass: 'loading-progress-line',
          },
        ],
      });
    }
  }
  
  public deleteServ(checkedRows: IDictionary, grid: GridEditable) {
    LoadingService.show(' ');
    Http.post('/deleteServ', { checkedRows }).then(() => {
      grid.cancelEditedRows();
      grid.datasource.get();
      grid.selectedRows = [];
      DialogService.hide();
      this.utilities.showAlert('alertSuccess', 'Excluído com sucesso!', 'green');
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
    }).finally(() => {
      DialogService.hide();
      LoadingService.hide();
    });
  }
  
  // Aba de Configuração
  
  public confirmDeleteConfig({ component }: IDictionary) {
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    this.checkedRowsTipo = grid.selectedRows;
    if (this.checkedRowsTipo.length === 0) this.utilities.showAlert('alert', 'Nenhum registro selecionado.', 'warning');
    else {
      DialogService.show({
        name: 'pme00200_excluiConfiguracaoServ',
        type: 'warning',
        title: 'Atenção',
        text: 'Deseja excluir os registros?',
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.deleteRowsConfigPrat(this.checkedRowsTipo, grid) },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
        ],
      });
    }
  }
  
  public deleteRowsConfigPrat(checkedRows: IDictionary, grid: GridEditable) {
    const buttonCancel = Metadata.getInstance<Button>('cancelButtonConf');
    const buttonSave = Metadata.getInstance<Button>('saveButtonConf');
    LoadingService.show(' ');
    Http.post('/deleteConfig', { checkedRows }).then(() => {
      grid.cancelEditedRows();
      grid.datasource.get();
      grid.selectedRows = [];
      this.getMaxSeq();
      buttonCancel.disabled = true;
      buttonSave.disabled = true;
      this.utilities.showAlert('alertSuccess', 'Excluído com sucesso!', 'green');
      DialogService.hide();
    }).catch((error: string) => {
      this.utilities.showAlert('alertError', `pme::${error}`, 'error');
      DialogService.hide();
    }).finally(() => {
      LoadingService.hide();
    });
  }
  
  public setServ(column: any) {
    if (column?.row?.CDSERVFILI) {
      const row = column?.row;
      this.selectedServ = row.CDSERVFILI;
      this.selectedNmServ = row.NMSERVICO ? `${row.CDSERVFILI} - ${row.NMSERVICO}` : row.SERVICO;

      if (this.isCentral) {
        this.showConfig = true;
        this.colsServ = 6;
        this.getMaxSeq();
      } else {
        this.showConfig = false;
        this.colsServ = 12;
      }
    } else {
      this.showConfig = false;
      this.colsServ = 12;
      this.selectedServ = '';
      this.selectedNmServ = '';
    }
  }

  public filterGridConfPrat() {
    const gridServ = Metadata.getInstance<GridEditable>('SERVICOS');
    const currentRow = gridServ.datasource.currentRow;
    const cdfilial = Metadata.getInstance<Select>('UNIDADE').value?.CDFILIAL || '';
    const gridConf = Metadata.getInstance<GridEditable>('CONFIGTIPOPRAT_SERV');
    if (currentRow.CDSERVFILI) {
      const conditions = [
        {
          name: 'CDFILIAL',
          operator: '=',
          value: cdfilial,
        },
        {
          name: 'CDSERVFILI',
          operator: '=',
          value: this.selectedServ,
        },
      ];
      if (gridConf.editing || this.showTipoPrat) {
        this.showTipoPrat = false;
        this.gridEditController.defaultState(gridConf);
      }
      this.resetTipoPrat();

      gridConf.datasource.filter = conditions;
      gridConf.datasource.get();
    }
  }

  private resetTipoPrat() {
    const tipoPrat = Metadata.getInstance<Select>('TIPOPRAT');
    tipoPrat.setValue([]);
    this.showTipoPrat = false;
  }
  
  /* Pega o maior valor de NRSEQCNFCARD do banco para o serviço e aunidade selecionada
    Para não gerar KEY repetida e diferenciar as linhas do grid na hora de
    adicionar no grid de Configuração Padrão,pois a chave primária da tabela só
    é inserida na hora de salvar recebendo o número da ordem que foi digitado;
  */
  public async getMaxSeq() {
    const cdfilial = Metadata.getInstance<Select>('UNIDADE').value.CDFILIAL;
    const parametros = {
      CDFILIAL: cdfilial,
      CDSERVFILI: this.selectedServ,
    };
    Http.post('dadosGridConfigPrat', { requestType: 'Row', row: parametros }).then((response) => {
      const rowsJaExistentes: IDictionary = response.data ? response.data.dataset.tipoprat : [];
      if (rowsJaExistentes.length > 0) {
        const nrseqExistentes = rowsJaExistentes.map((row: IDictionary) => row.NRSEQCNFCARD);
        this.nrseqconfcard = Math.max(...nrseqExistentes);
      }
    });
  }

  public addConf() {
    const buttonCancel = Metadata.getInstance<Button>('cancelButtonConf');
    const buttonSave = Metadata.getInstance<Button>('saveButtonConf');
    const configTipoPrat: GridEditable = Metadata.getInstance('CONFIGTIPOPRAT_SERV');
    if (this.utilities.centralIsValid()) {
      // this.showTipoPrat = true;
      // this.gridEditController.newRow = true;
      // this.gridEditController.onInlineEdit({ component: configTipoPrat });
      this.gridEditController.addRowSetFocusSecondPosition({ component: configTipoPrat });
      buttonCancel.disabled = false;
      buttonSave.disabled = false;
    }
  }
  
  /* Salva grid de configuração de prato;
    Sempre irá deletar todas as rows e inserir novamente(mesmo em caso de edição),
    pois precisa fazer o controle do parâmetro de paginação;
    Regra para salvar o NRPAGCNFCARD(paginação): A cada duas inserções onde a coluna IDIMPCNFCARD for igual a 'S'
    aumenta a paginação em 1.
  */
  public saveConfigPrat({ component }: IDictionary) {
    const gridConfig = Metadata.getInstance<GridEditable>('CONFIGTIPOPRAT_SERV');
    const editedRows = gridConfig.getEditedRows(false, true);
    
    const buttonCancel = Metadata.getInstance<Button>('cancelButtonConf');
    const buttonSave = Metadata.getInstance<Button>('saveButtonConf');
    
    if (gridConfig.isGridValid(true)) {
      if (editedRows.length > 0) {
        const cdfilial = Metadata.getInstance<Select>('UNIDADE').value.CDFILIAL;
        const tipoPrat = Metadata.getInstance<Select>('TIPOPRAT');
  
        const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;
  
        let rows: IDictionary = grid.getEditedRows(false, true);
        
        const newRows: IDictionary[] = [];
        // if (this.showTipoPrat) {
        // const addRows = tipoPrat.value;
        rows.forEach((row: IDictionary) => {
          if (row.__is_new && row.KEY === '') {
            row.CDTIPOPRAT.forEach((e: IDictionary) => {
              this.nrseqconfcard += 1;
              const newRow = {
                NRORDCNFCARD: this.nrseqconfcard,
                NRSEQCNFCARD: this.nrseqconfcard,
                IDIMPCNFCARD: row.IDIMPCNFCARD || 'N',
                IDOPCCNFCARD: row.IDOPCCNFCARD || 'N',
                NEW: 'S',
                CDTIPOPRAT: e.CDTIPOPRAT,
                NMTIPOPRAT: e.NMTIPOPRAT,
                __is_new: true,
              };
              newRows.push(newRow);
            });
          } else {
            if (Array.isArray(row.CDTIPOPRAT)) row.CDTIPOPRAT = row.CDTIPOPRAT[0];
            if (Array.isArray(row.NMTIPOPRAT)) row.NMTIPOPRAT = row.NMTIPOPRAT[0];
            row.NEW = 'N';
            newRows.push(row);
          }
        });
        // }
        rows = newRows;
  
        const parametros = {
          CDFILIAL: cdfilial,
          CDSERVFILI: this.selectedServ,
        };
        if (rows.length > 0) {
          Http.post('dadosGridConfigPrat', { requestType: 'Row', row: parametros }).then((response) => {
            const rowsJaExistentes: IDictionary = response.data ? response.data.dataset.tipoprat : [];
            const rowsTotal = rows.concat(rowsJaExistentes);
            // Usa uma key unica do objeto para utilizar na comparação
            // Pega o index de cada elemento do array.
            const uniqueData = rowsTotal.map((row: IDictionary) => row.NRORDCNFCARD)
              .map((cdprato: string, index: number, final: string) => final.indexOf(cdprato) === index && index)
              .filter((num: number) => rowsTotal[num])
              .map((position: number) => rowsTotal[position]);
            let inRow = 1;
            let inPag = 1;
            uniqueData.forEach((e: IDictionary) => {
              if (!e.IDIMPCNFCARD || e.IDIMPCNFCARD === 'N') {
                e.NRPAGCNFCARD = 0;
              } else if (e.IDIMPCNFCARD === 'S') {
                if (inRow === 1) {
                  e.NRPAGCNFCARD = inPag;
                  inRow = 2;
                } else {
                  e.NRPAGCNFCARD = inPag;
                  inRow = 1;
                  inPag += 1;
                }
              }
              e.CDFILIAL = cdfilial;
              e.CDSERVFILI = this.selectedServ;
              e.NRSEQCNFCARD = e.NRORDCNFCARD;
            });
            if (grid) LoadingService.show(' ');
            Http.post('/saveConfigPratServ', { requestType: 'Row', row: uniqueData }).then((callback) => {
              if (callback) {
                this.editable = false;
                this.utilities.showAlert('alertSuccess', 'Salvo com sucesso!', 'green');
                this.gridEditController.defaultState(grid);
                buttonCancel.disabled = true;
                buttonSave.disabled = true;
              }
  
              tipoPrat.setValue([]);
              this.showTipoPrat = false;
              this.gridConfEditing = false;
            }).catch(() => {
              this.utilities.showAlert('alertError', 'Impossível adicionar. Registro já existe.', 'error');
            }).finally(() => {
              if (grid) LoadingService.hide();
            });
          });
        }
      } else {
        this.editable = false;
        this.utilities.showAlert('alert', 'Nenhum registro editado.', 'yellow');
        this.gridEditController.defaultState(gridConfig);
        buttonCancel.disabled = true;
        buttonSave.disabled = true;
  
        this.showTipoPrat = false;
        this.gridConfEditing = false;
      }
    }
  }
  
  // Exportar Serviços
  public openExportModal() {
    const gridServ = Metadata.getInstance<GridEditable>('SERVICOS');
    gridServ.selectedRows = [];
    
    this.modalController.openModal();
  }
  
  public createModal() {
    this.modalController.createModal('pme/servico/modals/formExportService');
  }

  public destroyModal() {
    this.modalController.destroyModal();
  }
  
  public setFilterFieldsExport({ component }: IEventParam<SelectMultiple>) {
    let filterName = 'CDFILCENTPME';
    if (component.name === 'SERVICO_EXPORT') filterName = 'CDFILIAL';
    component.datasource.filter = this.returnConditionsUnidade(filterName);
    // component.datasource.get();
  }
  
  public exportService() {
    const formExport = Metadata.getInstance<Form>('formExportService');
    if (formExport.validate()) {
      const row = {
        UNIDADE_EXPORT: Metadata.getInstance<Select>('UNIDADE').value.CDFILIAL,
        UNIDADEAGREG: formExport.value.UNIDADEAGREG,
        SERVICO_EXPORT: formExport.value.SERVICO_EXPORT,
      };
      row.UNIDADEAGREG = row.UNIDADEAGREG.length > 0 ? row.UNIDADEAGREG.join('_') : 'T';
      row.SERVICO_EXPORT = row.SERVICO_EXPORT.length > 0 ? row.SERVICO_EXPORT.join('_') : 'T';
      LoadingService.show(' ');
      Http.post('/exportService', { requestType: 'Row', row }).then((response) => {
        if (response.data.dataset.success) {
          this.utilities.showAlert('alertSuccess', 'Exportação realizada com sucesso!', 'green');
          this.modalController.closeModal();
        } else {
          this.utilities.showAlert('alertError', 'Ocorreu um erro ao realizar a exportação!', 'red');
        }
      }).finally(() => {
        LoadingService.hide();
      });
    }
  }
  
  public produtoComponentProps = {
    component: 'ZdSelect',
    dataText: [
      {
        name: 'CDARVPROD',
        mask: (Config.masks.productMask as PmeMask).pattern,
      },
      'NMPRODUTO',
    ],
    formatterDataText: [
      {
        name: 'CDARVPROD',
        mask: (Config.masks.productMask as PmeMask).pattern,
      },
      'NMPRODUTO',
    ],
    dataValueOut: [
      {
        column: 'CDARVPROD',
        columnOnGrid: 'CDARVPROD',
      },
      {
        column: 'NMPRODUTO',
        columnOnGrid: 'NMPRODUTO',
      },
    ],
    dataValue: 'CDPRODUTO',
    dense: true,
    datasource: {
      uniqueKey: 'CDPRODUTO',
      route: '/prodUltimoNivel',
      type: 'rest',
      limit: 10,
      lazyLoad: true,
    },
    validations: {
      required: {
        message: 'Campo obrigatório',
      },
    },
  };
  
  public addRowServico({ component }: IDictionary) {
    const grid = this.utilities.returnGrid(component) as GridEditable;
    const row = grid.datasource.currentRow;

    Http.post('/returnDadosPadraoServ', { requestType: 'Row', row }).then((response) => {
      const result = response.data.dataset.result;
      if (result.length > 0) this.gridEditController.addRow({ component: grid });
      else this.gridEditController.addRowSetFocusSecondPosition({ component: grid });
    });
  }
  
  public returnDadosPadraoServ({ component }: IEventParam<GridEditable>) {
    const row = component.datasource.currentRow;

    Http.post('/returnDadosPadraoServ', { requestType: 'Row', row }).then((response) => {
      const result = response.data.dataset.result;
      const servico = this.utilities.returnColumn(component, 'SERVICO') as Column;
      const cdservfili = this.utilities.returnColumn(component, 'CDSERVFILI') as Column;
      const nmservicoinput = this.utilities.returnColumn(component, 'NMSERVICO') as Column;
      if (result.length > 0) {
        servico.isVisible = true;
        cdservfili.isVisible = false;
        nmservicoinput.isVisible = false;
      } else {
        servico.isVisible = false;
        cdservfili.isVisible = true;
        nmservicoinput.isVisible = true;
      }
    });
  }

  public closeConfig() {
    const configTipoPrat: GridEditable = Metadata.getInstance('CONFIGTIPOPRAT_SERV');
    this.gridEditController.cancelEditing({ component: configTipoPrat });
    const gridServ = Metadata.getInstance<GridEditable>('SERVICOS');
    
    this.showTipoPrat = false;
    this.showConfig = false;
    this.colsServ = 12;
    this.gridEditController.reload({ component: gridServ });
  }

  public reloadConfig({ component }: IDictionary) {
    const buttonCancel = Metadata.getInstance<Button>('cancelButtonConf');
    const buttonSave = Metadata.getInstance<Button>('saveButtonConf');
    const gridConfig: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    this.gridEditController.reload({ component });
    this.resetTipoPrat();
    this.gridEditController.newRow = false;
    this.gridEditController.onInlineEdit({ component: gridConfig });
    buttonCancel.disabled = true;
    buttonSave.disabled = true;
  }
  
  public habilitaBotao() {
    const buttonCancel = Metadata.getInstance<Button>('cancelButtonConf');
    const buttonSave = Metadata.getInstance<Button>('saveButtonConf');
    
    if (buttonCancel.disabled === true || buttonSave.disabled === true) {
      buttonCancel.disabled = false;
      buttonSave.disabled = false;
    }
  }
  
  /* Grupo de Serviço */
  
  get gridColsReturnValue(): number {
    return this.detailIsVisible ? 6 : 12;
  }
  
  public closeCardDetail() {
    const card = Metadata.getInstance<Card>('servicoCard');
    
    card.isVisible = false;
    this.detailIsVisible = false;
  }

  public setValueUnidade() {
    const unidade = Metadata.getInstance<Select>('unidadeServicoDetail');
    if (unidade.value === null) {
      const central = {
        CDFILIAL: this.utilities.getCdCentralLogada,
        NMFILIAL: this.utilities.getNmCentralLogada,
      };
      unidade.setValue(central);
    }
  }
  
  public onChangeGrupServCurrentRow({ component }: IEventParam<Datasource>) {
    this.cdGrupServ = component.currentRow.CDGRUPSERV;
    this.setValueUnidade();
    const unidade = Metadata.getInstance<Select>('unidadeServicoDetail');
    const centralLogada = this.appController.getCdCentral();
    const valorUnid = (unidade.value === null) ? centralLogada : unidade.value;
    
    if (this.cdGrupServ) {
      const gridServ = Metadata.getInstance<GridEditable>('servicoGridDetail');
      
      const conditions = [
        {
          name: 'P_CDGRUPSERV',
          operator: '=',
          value: component.currentRow.CDGRUPSERV,
        },
        {
          name: 'P_CDFILIAL',
          operator: '=',
          value: valorUnid,
        },
      ];
      
      gridServ.datasource.filter = conditions;
      gridServ.datasource.get();
      this.cardServicoVisible();
    }
  }
  
  public onChangeUnidadeDetail() {
    if (this.cdGrupServ) {
      const gridServ = Metadata.getInstance<GridEditable>('servicoGridDetail');
      const unidade = Metadata.getInstance<Select>('unidadeServicoDetail');
      const centralLogada = this.appController.getCdCentral();
      const valorUnid = (unidade.value === null) ? centralLogada : unidade.value;
      
      const conditions = [
        {
          name: 'P_CDGRUPSERV',
          operator: '=',
          value: this.cdGrupServ,
        },
        {
          name: 'P_CDFILIAL',
          operator: '=',
          value: valorUnid,
        },
      ];
      
      gridServ.datasource.filter = conditions;
      gridServ.datasource.get();
      this.cardServicoVisible();
    }
  }
  
  private cardServicoVisible() {
    const card = Metadata.getInstance<Card>('servicoCard');
    
    try {
      if (!this.gridEditController.newRow) {
        card.isVisible = true;
        this.detailIsVisible = true;
      }
    } catch (Error) {
      card.isVisible = false;
      this.detailIsVisible = false;
    }
  }
  
  public saveGrupoServico() {
    const gridGrupoServico: GridEditable = Metadata.getInstance('gridGrupoServico');
    const editedRows: IDictionary = gridGrupoServico.getEditedRows(false, true);

    if (gridGrupoServico.isGridValid(true)) {
      if (editedRows.length > 0) {
        editedRows.forEach((row: IDictionary) => {
          row.CDGRUPSERV = row.CDGRUPSERV.padStart(3, '0');
        });
        // const gridServicoDetail: GridEditable = Metadata.getInstance('servicoGridDetail');
  
        const datasourceName = 'grupserv';
        this.crudController.saveRows(editedRows, datasourceName, gridGrupoServico).then(() => {
          this.gridEditController.defaultState(gridGrupoServico);
          // gridServicoDetail.datasource.get();
          this.utilities.showAlert('alert', 'Salvo com sucesso!', 'success');
        }).catch((error: string) => {
          this.utilities.showAlert('alert', `pme::${error}`, 'error');
        });
      } else {
        this.gridEditController.defaultState(gridGrupoServico);
        this.utilities.showAlert('alert', 'Nenhum registro editado.', 'yellow');
      }
    }
  }
  
  /* public setFilterUnidadeDetail() {
    this.cdUnidadeServicoDetail = this.utilities.getCdCentralLogada;
  } */
  
  public changeCurrentConf({ component }: IEventParam<Datasource>) {
    const gridConf = Metadata.getInstance<GridEditable>('CONFIGTIPOPRAT_SERV');
    component.loading = true;
    if (this.gridConfEditing === false) gridConf.editing = false;
    if (gridConf.editing === false) {
      setTimeout(() => {
        this.formatData({ component });
      }, 200);
      this.gridConfEditing = true;
    } else component.loading = false;
  }
  
  private async formatData({ component }: IEventParam<Datasource>) {
    if (component.data.length > 0) {
      const data = [...component.data];
      await data.forEach((el) => {
        if (el.NMTIPOPRAT && !(Array.isArray(el.NMTIPOPRAT))) el.NMTIPOPRAT = [el.NMTIPOPRAT];
        if (el.CDTIPOPRAT && !(Array.isArray(el.CDTIPOPRAT))) el.CDTIPOPRAT = [el.CDTIPOPRAT];
      });
      component.data = data;
      component.loading = false;
    } else component.loading = false;
  }
  
  public setFilterRota({ component }: IEventParam<Select>) {
    const cdfilial = Metadata.getInstance<Select>('UNIDADE')?.value?.CDFILIAL || '';
    component.datasource.filter = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: cdfilial,
      },
    ];
    component.datasource.get();
  }
}
