import {
  Loader, Metadata, IDictionary, IEventParam, DatasourceFactory, Http,
} from '@zeedhi/core';
import {
  Select, ModalService, Modal, Form, SelectMultiple, Search, LoadingService, DialogService,
} from '@zeedhi/common';
import { CrosstabEditable } from '@zeedhi/zd-crosstab';

export class RelacionamentoController {
  public appController = Loader.getInstance('AppController');
  
  public modalAddRelacionamento!: Modal;
  
  public utilities = Loader.getInstance('Utilities');
  
  public utilitiesPLA = Loader.getInstance('UtilitiesPLA');
  
  public crudController = Loader.getInstance('CrudController');
  
  public get filterUnidade() {
    return [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
    ];
  }
  
  public changeValuesForm({ component }: IEventParam<Select>) {
    const form = component.parent as Form;
    if (component.name === 'UNIDADE') {
      form.value.SERVICO = null;
      form.value.TPCARD = null;
    } else if (component.name === 'SERVICO' || component.name === 'TPCARD') {
      form.value.TIPOPRAT = null;
    }
    if (form.name === 'formRelacionamento') this.setFilterCrossTab({ component });
  }
  
  public setFilterCrossTab({ component }: IEventParam<Select>) {
    const form = component.parent as Form;
    const crosstab = Metadata.getInstance<CrosstabEditable>('crosstabRelacionamento');
    if (form?.validate()) {
      crosstab.datasource.filter = [
        {
          name: 'CDFILIAL',
          operator: '=',
          value: form?.value?.UNIDADE ? form?.value?.UNIDADE?.CDFILIAL : '',
        },
        {
          name: 'CDSERVFILI',
          operator: '=',
          value: form?.value?.SERVICO?.length > 0 ? form?.value?.SERVICO?.map((el: any) => el.CDSERVFILI).join('_') : null,
        },
        {
          name: 'CDFILCENTPME',
          operator: '=',
          value: form?.value?.TPCARD?.length > 0 ? this.appController.getCdCentral() : null,
        },
        {
          name: 'CDTIPOCARD',
          operator: '=',
          value: form?.value?.TPCARD?.length > 0 ? form?.value?.TPCARD?.map((el: any) => el.CDTIPOCARD).join('_') : null,
        },
        {
          name: 'CDTIPOPRAT',
          operator: '=',
          value: form?.value?.TIPOPRAT?.length > 0 ? form?.value?.TIPOPRAT?.map((el: any) => el.CDTIPOPRAT).join('_') : null,
        },
      ];
      crosstab.datasource.get();
    } else {
      crosstab.datasource.data = [];
      crosstab.datasource.filter = [];
    }
  }
  
  public reducerCrossTab(str: any, item: IDictionary) {
    if (item.VAL && str) return `${str}, ${item.VAL}`;
    if (item.VAL) return `${item.VAL}`;
    return str;
  }

  public formatterCrossTab(value: any) {
    return value || 'Todos';
  }
  
  public addRelacionamento() {
    const form = Metadata.getInstance<Form>('formRelacionamento');
    if (this.utilities.centralIsValid() && form.validate()) {
      if (!this.modalAddRelacionamento) {
        this.createModalAddRelacionamento().then(() => {
          this.modalAddRelacionamento.show();
        });
      } else {
        this.modalAddRelacionamento.show();
      }
    }
  }
  
  private async createModalAddRelacionamento() {
    this.modalAddRelacionamento = await ModalService.createFromJsonPost('',
      { jsonPath: 'rotulacao/addRelacionamento' });
  }

  public closeModalAddRelacionamento() {
    this.modalAddRelacionamento.hide();
    this.modalAddRelacionamento.destroy();
    this.modalAddRelacionamento = this.utilities.modalEmpty;
  }
  
  public setFilterServ({ component }: IEventParam<Select>) {
    const form = component.parent as Form;
    component.datasource.filter = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: form.value?.UNIDADE?.CDFILIAL || '',
      },
      {
        name: 'CDGRUPSERV',
        operator: '=',
        value: 'T',
      },
      {
        name: 'CDGRUPFILI',
        operator: '=',
        value: 'T',
      },
      {
        name: 'IDTIPOSERV',
        operator: '=',
        value: this.utilitiesPLA.isMerenda() ? '' : 'N',
      },
    ];
    component.datasource.get();
  }
  
  public setIterableComponent() {
    const search = Metadata.getInstance<Search>('crosstab-search');
    search.setIterableComponent();
  }
  
  public setFilterTpCard({ component }: IEventParam<SelectMultiple>) {
    const form = component.parent as Form;
    component.datasource.filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDFILIAL',
        operator: '=',
        value: form.value?.UNIDADE ? form.value?.UNIDADE.CDFILIAL : null,
      },
    ];
    component.datasource.get();
  }
  
  public async saveRelacionamento() {
    // const crosstab = Metadata.getInstance<CrosstabEditable>('crosstabRelacionamento');
    const form = Metadata.getInstance<Form>('modalAddForm');
    if (form.validate()) {
      LoadingService.show(' ');
      let cdrelacaluno: number;
      const ds = DatasourceFactory.factory({
        uniqueKey: 'CDRELACALUNO',
        route: '/find/relacionamentoAluno',
        type: 'rest',
        filter: [
          {
            name: 'CDFILIAL',
            operator: '=',
            value: null,
          },
          {
            name: 'CDSERVFILI',
            operator: '=',
            value: null,
          },
          {
            name: 'CDFILCENTPME',
            operator: '=',
            value: null,
          },
          {
            name: 'CDTIPOCARD',
            operator: '=',
            value: null,
          },
          {
            name: 'CDTIPOPRAT',
            operator: '=',
            value: null,
          },
        ],
        // loadAll: true,
      });
      const result = await ds.get();
      // const total = ds.total;
      if (result.length > 0) cdrelacaluno = result[0].MAX + 1;
      else cdrelacaluno = 1;
      const row = [{
        CDFILIAL: form.value.UNIDADE?.CDFILIAL,
        CDSERVFILI: form.value.SERVICO?.CDSERVFILI,
        CDFILCENTPME: form.value.TPCARD ? this.appController.getCdCentral() : null,
        CDTIPOCARD: form.value.TPCARD ? form.value.TPCARD.CDTIPOCARD : null,
        CDTIPOPRAT: form.value.TIPOPRAT ? form.value.TIPOPRAT.CDTIPOPRAT : null,
        CDRELACALUNO: cdrelacaluno,
        CDALUNO: form.value.ALUNO?.CDALUNO,
        __is_new: true,
      }];
      // this.crudController.saveRows(rows, 'relacionamento', null).then((response: any) => {
      Http.post('/relateAluno', { requestType: 'Row', row }).then((response: any) => {
        if (response?.data?.dataset?.relateAluno?.length === 0) {
          const unidade = Metadata.getInstance<Form>('formRelacionamento').getChildInstance<Select>('UNIDADE');
          this.setFilterCrossTab({ component: unidade });
          this.closeModalAddRelacionamento();
        } else if (response?.data?.dataset?.relateAluno?.length > 0) {
          this.utilities.showAlert('alert', `pme::${response?.data?.dataset?.relateAluno}`, 'error');
        } else this.utilities.showAlert('alert', `${response}`, 'error');
      }).catch((error: string) => {
        this.utilities.showAlert('alert', `pme::${error}`, 'error');
      }).finally(() => {
        LoadingService.hide();
      });
    }
  }
  
  public reloadCrosstab() {
    const crosstab = Metadata.getInstance<CrosstabEditable>('crosstabRelacionamento');
    // const addButton = Metadata.getInstance<Button>('addButton');
    // const deleteButton = Metadata.getInstance<Button>('deleteButton');
    crosstab.datasource.get().then(() => {
      // if (addButton) addButton.disabled = false;
      // if (deleteButton) deleteButton.disabled = false;
    });
  }
  
  public deleteRelacionamento() {
    const crosstab = Metadata.getInstance<CrosstabEditable>('crosstabRelacionamento');
    if (Object.keys(crosstab.selectedCell as IDictionary).length > 0 && ((crosstab.selectedCell as IDictionary)?.labels
      || (crosstab.selectedCell as IDictionary)?.field?.name === 'NMTIPOCARD')) {
      DialogService.show({
        name: 'excluiRelacionamento',
        type: 'warning',
        title: 'Atenção',
        text: 'Deseja excluir o registro?',
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.confirmDeleteRelacionamento(crosstab) },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
        ],
      });
    } else this.utilities.showAlert('alert', 'pme::celulaDeletavel2', 'error');
  }
  
  private confirmDeleteRelacionamento(crosstab: CrosstabEditable) {
    LoadingService.show(' ');
    this.crudController.deleteRows(crosstab.selectedCell?.rows, 'relacionamento').then((result: any) => {
      if (result?.data?.notifications?.length > 0) {
        result.data.notifications.forEach((el: any) => {
          this.utilities.showAlert(el.type, el.message, el.type);
        });
        crosstab.datasource.get();
        DialogService.hide();
      } else this.utilities.showAlert('alert', `${result}`, 'error');
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
    }).finally(() => {
      LoadingService.hide();
    });
  }
  
  public setFilterTpPrat({ component }: IEventParam<Select>) {
    const form = component.parent as Form;
    component.datasource.filter = [
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: Array.isArray(form?.value?.TPCARD) && form?.value?.TPCARD.length > 0
          ? form.value?.TPCARD.map((el: any) => el.CDTIPOCARD).join('_') : form?.value?.TPCARD?.CDTIPOCARD || null,
      },
      {
        name: 'CDSERVFILI',
        operator: '=',
        value: Array.isArray(form?.value?.SERVICO) && form?.value?.SERVICO.length > 0
          ? form.value?.SERVICO.map((el: any) => el.CDSERVFILI).join('_') : form?.value?.SERVICO?.CDSERVFILI || null,
      },
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
    ];
    component.datasource.get();
  }
  
  public getUnidadeSelecionada({ component }: IEventParam<Select>) {
    const form = Metadata.getInstance<Form>('formRelacionamento');
    component.setValue(form?.value?.UNIDADE?.CDFILIAL, false);
    // component.setValue({ CDFILIAL: form?.value?.UNIDADE?.CDFILIAL, NMFILIAL: form?.value?.UNIDADE?.CDFILIAL });
  }
}
